# mixpeek
This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.3.0
- Package version: 1.3.0
- Generator version: 7.14.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://mixpeek.com/contact](https://mixpeek.com/contact)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import mixpeek
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import mixpeek
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import mixpeek
from mixpeek.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.mixpeek.com
# See configuration.py for a list of all supported configuration parameters.
configuration = mixpeek.Configuration(
    host = "https://api.mixpeek.com"
)



# Enter a context with an instance of the API client
with mixpeek.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = mixpeek.AdhocRetrieversApi(api_client)
    adhoc_execute_request = mixpeek.AdhocExecuteRequest() # AdhocExecuteRequest | 
    return_presigned_urls = False # bool |  (optional) (default to False)
    return_vectors = False # bool |  (optional) (default to False)
    authorization = 'authorization_example' # str | REQUIRED: Bearer token authentication using your API key. Format: 'Bearer sk_xxxxxxxxxxxxx'. You can create API keys in the Mixpeek dashboard under Organization Settings. (optional)
    x_namespace = 'x_namespace_example' # str | REQUIRED: Namespace identifier for scoping this request. All resources (collections, buckets, taxonomies, etc.) are scoped to a namespace. You can provide either the namespace name or namespace ID. Format: ns_xxxxxxxxxxxxx (ID) or a custom name like 'my-namespace' (optional)

    try:
        # Execute Adhoc Retriever
        api_response = api_instance.execute_adhoc_retriever(adhoc_execute_request, return_presigned_urls=return_presigned_urls, return_vectors=return_vectors, authorization=authorization, x_namespace=x_namespace)
        print("The response of AdhocRetrieversApi->execute_adhoc_retriever:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AdhocRetrieversApi->execute_adhoc_retriever: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.mixpeek.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdhocRetrieversApi* | [**execute_adhoc_retriever**](docs/AdhocRetrieversApi.md#execute_adhoc_retriever) | **POST** /v1/retrievers/execute | Execute Adhoc Retriever
*AdhocRetrieversApi* | [**get_adhoc_execution_retrievers**](docs/AdhocRetrieversApi.md#get_adhoc_execution_retrievers) | **GET** /v1/retrievers/executions/{execution_id} | Get Adhoc Execution
*AdhocRetrieversApi* | [**list_adhoc_executions_retrievers**](docs/AdhocRetrieversApi.md#list_adhoc_executions_retrievers) | **POST** /v1/retrievers/executions/list | List Adhoc Executions
*AgentSessionsApi* | [**create_session_agents**](docs/AgentSessionsApi.md#create_session_agents) | **POST** /v1/agents/sessions | Create Session
*AgentSessionsApi* | [**detect_intent_agents_sessions**](docs/AgentSessionsApi.md#detect_intent_agents_sessions) | **POST** /v1/agents/sessions/intent/detect | Detect Intent
*AgentSessionsApi* | [**get_history_agents_sessions**](docs/AgentSessionsApi.md#get_history_agents_sessions) | **GET** /v1/agents/sessions/{session_id}/history | Get History
*AgentSessionsApi* | [**get_session_agents**](docs/AgentSessionsApi.md#get_session_agents) | **GET** /v1/agents/sessions/{session_id} | Get Session
*AgentSessionsApi* | [**list_sessions_agents**](docs/AgentSessionsApi.md#list_sessions_agents) | **POST** /v1/agents/sessions/list | List Sessions
*AgentSessionsApi* | [**list_tools_agents_sessions**](docs/AgentSessionsApi.md#list_tools_agents_sessions) | **GET** /v1/agents/sessions/tools | List Tools
*AgentSessionsApi* | [**patch_session_agents**](docs/AgentSessionsApi.md#patch_session_agents) | **PATCH** /v1/agents/sessions/{session_id} | Patch Session
*AgentSessionsApi* | [**respond_to_confirmation_agents_sessions**](docs/AgentSessionsApi.md#respond_to_confirmation_agents_sessions) | **POST** /v1/agents/sessions/{session_id}/confirmations/{confirmation_id} | Respond To Confirmation
*AgentSessionsApi* | [**send_message_agents_sessions**](docs/AgentSessionsApi.md#send_message_agents_sessions) | **POST** /v1/agents/sessions/{session_id}/messages | Send Message
*AgentSessionsApi* | [**submit_feedback_agents_sessions**](docs/AgentSessionsApi.md#submit_feedback_agents_sessions) | **POST** /v1/agents/sessions/{session_id}/feedback | Submit Feedback
*AgentSessionsApi* | [**terminate_session_agents**](docs/AgentSessionsApi.md#terminate_session_agents) | **DELETE** /v1/agents/sessions/{session_id} | Terminate Session
*AlertsApi* | [**create_alert**](docs/AlertsApi.md#create_alert) | **POST** /v1/alerts | Create Alert
*AlertsApi* | [**create_alert_0**](docs/AlertsApi.md#create_alert_0) | **POST** /v1/alerts | Create Alert
*AlertsApi* | [**delete_alert**](docs/AlertsApi.md#delete_alert) | **DELETE** /v1/alerts/{alert_identifier} | Delete Alert
*AlertsApi* | [**delete_alert_0**](docs/AlertsApi.md#delete_alert_0) | **DELETE** /v1/alerts/{alert_identifier} | Delete Alert
*AlertsApi* | [**get_alert**](docs/AlertsApi.md#get_alert) | **GET** /v1/alerts/{alert_identifier} | Get Alert
*AlertsApi* | [**get_alert_0**](docs/AlertsApi.md#get_alert_0) | **GET** /v1/alerts/{alert_identifier} | Get Alert
*AlertsApi* | [**list_alert_executions**](docs/AlertsApi.md#list_alert_executions) | **GET** /v1/alerts/{alert_identifier}/executions | List Alert Executions
*AlertsApi* | [**list_alert_executions_0**](docs/AlertsApi.md#list_alert_executions_0) | **GET** /v1/alerts/{alert_identifier}/executions | List Alert Executions
*AlertsApi* | [**list_alerts**](docs/AlertsApi.md#list_alerts) | **POST** /v1/alerts/list | List Alerts
*AlertsApi* | [**list_alerts_0**](docs/AlertsApi.md#list_alerts_0) | **POST** /v1/alerts/list | List Alerts
*AlertsApi* | [**list_all_executions_alerts**](docs/AlertsApi.md#list_all_executions_alerts) | **GET** /v1/alerts/executions | List All Executions
*AlertsApi* | [**list_all_executions_alerts_0**](docs/AlertsApi.md#list_all_executions_alerts_0) | **GET** /v1/alerts/executions | List All Executions
*AlertsApi* | [**patch_alert**](docs/AlertsApi.md#patch_alert) | **PATCH** /v1/alerts/{alert_identifier} | Update Alert
*AlertsApi* | [**patch_alert_0**](docs/AlertsApi.md#patch_alert_0) | **PATCH** /v1/alerts/{alert_identifier} | Update Alert
*AnalyticsApi* | [**analyze_bottlenecks_analytics_performance_engine**](docs/AnalyticsApi.md#analyze_bottlenecks_analytics_performance_engine) | **GET** /v1/analytics/performance/engine/bottlenecks | Analyze Bottlenecks
*AnalyticsApi* | [**analyze_bottlenecks_analytics_performance_engine_0**](docs/AnalyticsApi.md#analyze_bottlenecks_analytics_performance_engine_0) | **GET** /v1/analytics/performance/engine/bottlenecks | Analyze Bottlenecks
*AnalyticsApi* | [**analyze_for_tuning_analytics_retrievers**](docs/AnalyticsApi.md#analyze_for_tuning_analytics_retrievers) | **POST** /v1/analytics/retrievers/{retriever_id}/analyze-tuning | Analyze For Tuning
*AnalyticsApi* | [**analyze_for_tuning_analytics_retrievers_0**](docs/AnalyticsApi.md#analyze_for_tuning_analytics_retrievers_0) | **POST** /v1/analytics/retrievers/{retriever_id}/analyze-tuning | Analyze For Tuning
*AnalyticsApi* | [**get_assignment_metrics_analytics_taxonomies_taxonomy**](docs/AnalyticsApi.md#get_assignment_metrics_analytics_taxonomies_taxonomy) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/assignments | Get Assignment Metrics
*AnalyticsApi* | [**get_assignment_metrics_analytics_taxonomies_taxonomy_0**](docs/AnalyticsApi.md#get_assignment_metrics_analytics_taxonomies_taxonomy_0) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/assignments | Get Assignment Metrics
*AnalyticsApi* | [**get_batch_diagnostics_analytics_performance_batches**](docs/AnalyticsApi.md#get_batch_diagnostics_analytics_performance_batches) | **GET** /v1/analytics/performance/batches/{batch_id}/diagnostics | Get Batch Diagnostics
*AnalyticsApi* | [**get_batch_diagnostics_analytics_performance_batches_0**](docs/AnalyticsApi.md#get_batch_diagnostics_analytics_performance_batches_0) | **GET** /v1/analytics/performance/batches/{batch_id}/diagnostics | Get Batch Diagnostics
*AnalyticsApi* | [**get_bucket_health_analytics**](docs/AnalyticsApi.md#get_bucket_health_analytics) | **GET** /v1/analytics/buckets/{bucket_id}/health | Get Bucket Health
*AnalyticsApi* | [**get_bucket_health_analytics_0**](docs/AnalyticsApi.md#get_bucket_health_analytics_0) | **GET** /v1/analytics/buckets/{bucket_id}/health | Get Bucket Health
*AnalyticsApi* | [**get_bucket_storage_analytics**](docs/AnalyticsApi.md#get_bucket_storage_analytics) | **GET** /v1/analytics/buckets/{bucket_id}/storage | Get Bucket Storage
*AnalyticsApi* | [**get_bucket_storage_analytics_0**](docs/AnalyticsApi.md#get_bucket_storage_analytics_0) | **GET** /v1/analytics/buckets/{bucket_id}/storage | Get Bucket Storage
*AnalyticsApi* | [**get_bucket_usage_analytics**](docs/AnalyticsApi.md#get_bucket_usage_analytics) | **GET** /v1/analytics/buckets/{bucket_id}/usage | Get Bucket Usage
*AnalyticsApi* | [**get_bucket_usage_analytics_0**](docs/AnalyticsApi.md#get_bucket_usage_analytics_0) | **GET** /v1/analytics/buckets/{bucket_id}/usage | Get Bucket Usage
*AnalyticsApi* | [**get_cache_performance_analytics_retrievers**](docs/AnalyticsApi.md#get_cache_performance_analytics_retrievers) | **GET** /v1/analytics/retrievers/{retriever_id}/cache-performance | Get Cache Performance
*AnalyticsApi* | [**get_cache_performance_analytics_retrievers_0**](docs/AnalyticsApi.md#get_cache_performance_analytics_retrievers_0) | **GET** /v1/analytics/retrievers/{retriever_id}/cache-performance | Get Cache Performance
*AnalyticsApi* | [**get_collection_overview_analytics**](docs/AnalyticsApi.md#get_collection_overview_analytics) | **GET** /v1/analytics/collections/{collection_id}/overview | Get Collection Overview
*AnalyticsApi* | [**get_collection_overview_analytics_0**](docs/AnalyticsApi.md#get_collection_overview_analytics_0) | **GET** /v1/analytics/collections/{collection_id}/overview | Get Collection Overview
*AnalyticsApi* | [**get_compound_index_patterns_analytics_namespaces_indexes**](docs/AnalyticsApi.md#get_compound_index_patterns_analytics_namespaces_indexes) | **GET** /v1/analytics/namespaces/indexes/compound-patterns | Get Compound Index Patterns
*AnalyticsApi* | [**get_compound_index_patterns_analytics_namespaces_indexes_0**](docs/AnalyticsApi.md#get_compound_index_patterns_analytics_namespaces_indexes_0) | **GET** /v1/analytics/namespaces/indexes/compound-patterns | Get Compound Index Patterns
*AnalyticsApi* | [**get_confidence_distribution_analytics_taxonomies_taxonomy**](docs/AnalyticsApi.md#get_confidence_distribution_analytics_taxonomies_taxonomy) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/confidence | Get Confidence Distribution
*AnalyticsApi* | [**get_confidence_distribution_analytics_taxonomies_taxonomy_0**](docs/AnalyticsApi.md#get_confidence_distribution_analytics_taxonomies_taxonomy_0) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/confidence | Get Confidence Distribution
*AnalyticsApi* | [**get_document_growth_analytics**](docs/AnalyticsApi.md#get_document_growth_analytics) | **GET** /v1/analytics/collections/{collection_id}/growth | Get Document Growth
*AnalyticsApi* | [**get_document_growth_analytics_0**](docs/AnalyticsApi.md#get_document_growth_analytics_0) | **GET** /v1/analytics/collections/{collection_id}/growth | Get Document Growth
*AnalyticsApi* | [**get_engine_performance_analytics**](docs/AnalyticsApi.md#get_engine_performance_analytics) | **GET** /v1/analytics/performance/engine | Get Engine Performance
*AnalyticsApi* | [**get_engine_performance_analytics_0**](docs/AnalyticsApi.md#get_engine_performance_analytics_0) | **GET** /v1/analytics/performance/engine | Get Engine Performance
*AnalyticsApi* | [**get_engine_stage_breakdown_analytics_performance**](docs/AnalyticsApi.md#get_engine_stage_breakdown_analytics_performance) | **GET** /v1/analytics/performance/engine/stages | Get Engine Stage Breakdown
*AnalyticsApi* | [**get_engine_stage_breakdown_analytics_performance_0**](docs/AnalyticsApi.md#get_engine_stage_breakdown_analytics_performance_0) | **GET** /v1/analytics/performance/engine/stages | Get Engine Stage Breakdown
*AnalyticsApi* | [**get_enrichment_history_analytics_taxonomies_taxonomy**](docs/AnalyticsApi.md#get_enrichment_history_analytics_taxonomies_taxonomy) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/enrichments | Get Enrichment History
*AnalyticsApi* | [**get_enrichment_history_analytics_taxonomies_taxonomy_0**](docs/AnalyticsApi.md#get_enrichment_history_analytics_taxonomies_taxonomy_0) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/enrichments | Get Enrichment History
*AnalyticsApi* | [**get_execution_history_analytics_clusters**](docs/AnalyticsApi.md#get_execution_history_analytics_clusters) | **GET** /v1/analytics/clusters/{cluster_id}/execution-history | Get Execution History
*AnalyticsApi* | [**get_execution_history_analytics_clusters_0**](docs/AnalyticsApi.md#get_execution_history_analytics_clusters_0) | **GET** /v1/analytics/clusters/{cluster_id}/execution-history | Get Execution History
*AnalyticsApi* | [**get_extractor_breakdown_analytics_performance_engine**](docs/AnalyticsApi.md#get_extractor_breakdown_analytics_performance_engine) | **GET** /v1/analytics/performance/engine/extractors | Get Extractor Breakdown
*AnalyticsApi* | [**get_extractor_breakdown_analytics_performance_engine_0**](docs/AnalyticsApi.md#get_extractor_breakdown_analytics_performance_engine_0) | **GET** /v1/analytics/performance/engine/extractors | Get Extractor Breakdown
*AnalyticsApi* | [**get_extractor_performance_analytics**](docs/AnalyticsApi.md#get_extractor_performance_analytics) | **GET** /v1/analytics/extractors/performance | Get Extractor Performance
*AnalyticsApi* | [**get_extractor_performance_analytics_0**](docs/AnalyticsApi.md#get_extractor_performance_analytics_0) | **GET** /v1/analytics/extractors/performance | Get Extractor Performance
*AnalyticsApi* | [**get_extractor_performance_analytics_1**](docs/AnalyticsApi.md#get_extractor_performance_analytics_1) | **GET** /v1/analytics/collections/{collection_id}/extractors | Get Extractor Performance
*AnalyticsApi* | [**get_extractor_performance_analytics_2**](docs/AnalyticsApi.md#get_extractor_performance_analytics_2) | **GET** /v1/analytics/collections/{collection_id}/extractors | Get Extractor Performance
*AnalyticsApi* | [**get_failure_analysis_analytics**](docs/AnalyticsApi.md#get_failure_analysis_analytics) | **GET** /v1/analytics/collections/{collection_id}/failures | Get Failure Analysis
*AnalyticsApi* | [**get_failure_analysis_analytics_0**](docs/AnalyticsApi.md#get_failure_analysis_analytics_0) | **GET** /v1/analytics/collections/{collection_id}/failures | Get Failure Analysis
*AnalyticsApi* | [**get_failure_analysis_analytics_clusters**](docs/AnalyticsApi.md#get_failure_analysis_analytics_clusters) | **GET** /v1/analytics/clusters/{cluster_id}/failures | Get Failure Analysis
*AnalyticsApi* | [**get_failure_analysis_analytics_clusters_0**](docs/AnalyticsApi.md#get_failure_analysis_analytics_clusters_0) | **GET** /v1/analytics/clusters/{cluster_id}/failures | Get Failure Analysis
*AnalyticsApi* | [**get_field_performance_analytics_namespaces**](docs/AnalyticsApi.md#get_field_performance_analytics_namespaces) | **GET** /v1/analytics/namespaces/fields/performance | Get Field Performance
*AnalyticsApi* | [**get_field_performance_analytics_namespaces_0**](docs/AnalyticsApi.md#get_field_performance_analytics_namespaces_0) | **GET** /v1/analytics/namespaces/fields/performance | Get Field Performance
*AnalyticsApi* | [**get_field_usage_analytics_indexes**](docs/AnalyticsApi.md#get_field_usage_analytics_indexes) | **GET** /v1/analytics/indexes/usage | Get Field Usage
*AnalyticsApi* | [**get_field_usage_analytics_indexes_0**](docs/AnalyticsApi.md#get_field_usage_analytics_indexes_0) | **GET** /v1/analytics/indexes/usage | Get Field Usage
*AnalyticsApi* | [**get_index_recommendations_analytics_namespaces_indexes**](docs/AnalyticsApi.md#get_index_recommendations_analytics_namespaces_indexes) | **GET** /v1/analytics/namespaces/indexes/recommendations | Get Index Recommendations
*AnalyticsApi* | [**get_index_recommendations_analytics_namespaces_indexes_0**](docs/AnalyticsApi.md#get_index_recommendations_analytics_namespaces_indexes_0) | **GET** /v1/analytics/namespaces/indexes/recommendations | Get Index Recommendations
*AnalyticsApi* | [**get_index_suggestions_analytics_indexes**](docs/AnalyticsApi.md#get_index_suggestions_analytics_indexes) | **GET** /v1/analytics/indexes/suggestions | Get Index Suggestions
*AnalyticsApi* | [**get_index_suggestions_analytics_indexes_0**](docs/AnalyticsApi.md#get_index_suggestions_analytics_indexes_0) | **GET** /v1/analytics/indexes/suggestions | Get Index Suggestions
*AnalyticsApi* | [**get_inference_performance_analytics**](docs/AnalyticsApi.md#get_inference_performance_analytics) | **GET** /v1/analytics/inference/performance | Get Inference Performance
*AnalyticsApi* | [**get_inference_performance_analytics_0**](docs/AnalyticsApi.md#get_inference_performance_analytics_0) | **GET** /v1/analytics/inference/performance | Get Inference Performance
*AnalyticsApi* | [**get_label_distribution_analytics_taxonomies_taxonomy**](docs/AnalyticsApi.md#get_label_distribution_analytics_taxonomies_taxonomy) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/labels | Get Label Distribution
*AnalyticsApi* | [**get_label_distribution_analytics_taxonomies_taxonomy_0**](docs/AnalyticsApi.md#get_label_distribution_analytics_taxonomies_taxonomy_0) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/labels | Get Label Distribution
*AnalyticsApi* | [**get_latency_metrics_analytics**](docs/AnalyticsApi.md#get_latency_metrics_analytics) | **GET** /v1/analytics/collections/{collection_id}/latency | Get Latency Metrics
*AnalyticsApi* | [**get_latency_metrics_analytics_0**](docs/AnalyticsApi.md#get_latency_metrics_analytics_0) | **GET** /v1/analytics/collections/{collection_id}/latency | Get Latency Metrics
*AnalyticsApi* | [**get_most_queried_fields_analytics_namespaces**](docs/AnalyticsApi.md#get_most_queried_fields_analytics_namespaces) | **GET** /v1/analytics/namespaces/fields/most-queried | Get Most Queried Fields
*AnalyticsApi* | [**get_most_queried_fields_analytics_namespaces_0**](docs/AnalyticsApi.md#get_most_queried_fields_analytics_namespaces_0) | **GET** /v1/analytics/namespaces/fields/most-queried | Get Most Queried Fields
*AnalyticsApi* | [**get_namespace_summary_analytics**](docs/AnalyticsApi.md#get_namespace_summary_analytics) | **GET** /v1/analytics/namespaces/summary | Get Namespace Summary
*AnalyticsApi* | [**get_namespace_summary_analytics_0**](docs/AnalyticsApi.md#get_namespace_summary_analytics_0) | **GET** /v1/analytics/namespaces/summary | Get Namespace Summary
*AnalyticsApi* | [**get_retriever_performance_analytics**](docs/AnalyticsApi.md#get_retriever_performance_analytics) | **GET** /v1/analytics/retrievers/{retriever_id}/performance | Get Retriever Performance
*AnalyticsApi* | [**get_retriever_performance_analytics_0**](docs/AnalyticsApi.md#get_retriever_performance_analytics_0) | **GET** /v1/analytics/retrievers/{retriever_id}/performance | Get Retriever Performance
*AnalyticsApi* | [**get_retriever_signals_analytics**](docs/AnalyticsApi.md#get_retriever_signals_analytics) | **GET** /v1/analytics/retrievers/{retriever_id}/signals | Get Retriever Signals
*AnalyticsApi* | [**get_retriever_signals_analytics_0**](docs/AnalyticsApi.md#get_retriever_signals_analytics_0) | **GET** /v1/analytics/retrievers/{retriever_id}/signals | Get Retriever Signals
*AnalyticsApi* | [**get_slow_queries_analytics_namespaces**](docs/AnalyticsApi.md#get_slow_queries_analytics_namespaces) | **GET** /v1/analytics/namespaces/queries/slow | Get Slow Queries
*AnalyticsApi* | [**get_slow_queries_analytics_namespaces_0**](docs/AnalyticsApi.md#get_slow_queries_analytics_namespaces_0) | **GET** /v1/analytics/namespaces/queries/slow | Get Slow Queries
*AnalyticsApi* | [**get_slowest_operations_analytics_performance_engine_slow**](docs/AnalyticsApi.md#get_slowest_operations_analytics_performance_engine_slow) | **GET** /v1/analytics/performance/engine/slow-operations | Get Slowest Operations
*AnalyticsApi* | [**get_slowest_operations_analytics_performance_engine_slow_0**](docs/AnalyticsApi.md#get_slowest_operations_analytics_performance_engine_slow_0) | **GET** /v1/analytics/performance/engine/slow-operations | Get Slowest Operations
*AnalyticsApi* | [**get_slowest_queries_analytics_retrievers_id_slow**](docs/AnalyticsApi.md#get_slowest_queries_analytics_retrievers_id_slow) | **GET** /v1/analytics/retrievers/{retriever_id}/slow-queries | Get Slowest Queries
*AnalyticsApi* | [**get_slowest_queries_analytics_retrievers_id_slow_0**](docs/AnalyticsApi.md#get_slowest_queries_analytics_retrievers_id_slow_0) | **GET** /v1/analytics/retrievers/{retriever_id}/slow-queries | Get Slowest Queries
*AnalyticsApi* | [**get_stage_breakdown_analytics_retrievers**](docs/AnalyticsApi.md#get_stage_breakdown_analytics_retrievers) | **GET** /v1/analytics/retrievers/{retriever_id}/stages | Get Stage Breakdown
*AnalyticsApi* | [**get_stage_breakdown_analytics_retrievers_0**](docs/AnalyticsApi.md#get_stage_breakdown_analytics_retrievers_0) | **GET** /v1/analytics/retrievers/{retriever_id}/stages | Get Stage Breakdown
*AnalyticsApi* | [**get_sync_comparison_analytics_buckets**](docs/AnalyticsApi.md#get_sync_comparison_analytics_buckets) | **GET** /v1/analytics/buckets/{bucket_id}/sync-comparison | Get Sync Comparison
*AnalyticsApi* | [**get_sync_comparison_analytics_buckets_0**](docs/AnalyticsApi.md#get_sync_comparison_analytics_buckets_0) | **GET** /v1/analytics/buckets/{bucket_id}/sync-comparison | Get Sync Comparison
*AnalyticsApi* | [**get_sync_performance_analytics_buckets**](docs/AnalyticsApi.md#get_sync_performance_analytics_buckets) | **GET** /v1/analytics/buckets/{bucket_id}/sync-performance | Get Sync Performance
*AnalyticsApi* | [**get_sync_performance_analytics_buckets_0**](docs/AnalyticsApi.md#get_sync_performance_analytics_buckets_0) | **GET** /v1/analytics/buckets/{bucket_id}/sync-performance | Get Sync Performance
*AnalyticsApi* | [**get_upload_performance_analytics_buckets**](docs/AnalyticsApi.md#get_upload_performance_analytics_buckets) | **GET** /v1/analytics/buckets/{bucket_id}/upload-performance | Get Upload Performance
*AnalyticsApi* | [**get_upload_performance_analytics_buckets_0**](docs/AnalyticsApi.md#get_upload_performance_analytics_buckets_0) | **GET** /v1/analytics/buckets/{bucket_id}/upload-performance | Get Upload Performance
*AnalyticsApi* | [**get_usage_summary_analytics**](docs/AnalyticsApi.md#get_usage_summary_analytics) | **GET** /v1/analytics/usage/summary | Get Usage Summary
*AnalyticsApi* | [**get_usage_summary_analytics_0**](docs/AnalyticsApi.md#get_usage_summary_analytics_0) | **GET** /v1/analytics/usage/summary | Get Usage Summary
*AnalyticsBucketsApi* | [**get_bucket_health_analytics**](docs/AnalyticsBucketsApi.md#get_bucket_health_analytics) | **GET** /v1/analytics/buckets/{bucket_id}/health | Get Bucket Health
*AnalyticsBucketsApi* | [**get_bucket_storage_analytics**](docs/AnalyticsBucketsApi.md#get_bucket_storage_analytics) | **GET** /v1/analytics/buckets/{bucket_id}/storage | Get Bucket Storage
*AnalyticsBucketsApi* | [**get_bucket_usage_analytics**](docs/AnalyticsBucketsApi.md#get_bucket_usage_analytics) | **GET** /v1/analytics/buckets/{bucket_id}/usage | Get Bucket Usage
*AnalyticsBucketsApi* | [**get_sync_comparison_analytics_buckets**](docs/AnalyticsBucketsApi.md#get_sync_comparison_analytics_buckets) | **GET** /v1/analytics/buckets/{bucket_id}/sync-comparison | Get Sync Comparison
*AnalyticsBucketsApi* | [**get_sync_performance_analytics_buckets**](docs/AnalyticsBucketsApi.md#get_sync_performance_analytics_buckets) | **GET** /v1/analytics/buckets/{bucket_id}/sync-performance | Get Sync Performance
*AnalyticsBucketsApi* | [**get_upload_performance_analytics_buckets**](docs/AnalyticsBucketsApi.md#get_upload_performance_analytics_buckets) | **GET** /v1/analytics/buckets/{bucket_id}/upload-performance | Get Upload Performance
*AnalyticsClustersApi* | [**get_execution_history_analytics_clusters**](docs/AnalyticsClustersApi.md#get_execution_history_analytics_clusters) | **GET** /v1/analytics/clusters/{cluster_id}/execution-history | Get Execution History
*AnalyticsClustersApi* | [**get_failure_analysis_analytics_clusters**](docs/AnalyticsClustersApi.md#get_failure_analysis_analytics_clusters) | **GET** /v1/analytics/clusters/{cluster_id}/failures | Get Failure Analysis
*AnalyticsCollectionsApi* | [**get_collection_overview_analytics**](docs/AnalyticsCollectionsApi.md#get_collection_overview_analytics) | **GET** /v1/analytics/collections/{collection_id}/overview | Get Collection Overview
*AnalyticsCollectionsApi* | [**get_document_growth_analytics**](docs/AnalyticsCollectionsApi.md#get_document_growth_analytics) | **GET** /v1/analytics/collections/{collection_id}/growth | Get Document Growth
*AnalyticsCollectionsApi* | [**get_extractor_performance_analytics**](docs/AnalyticsCollectionsApi.md#get_extractor_performance_analytics) | **GET** /v1/analytics/collections/{collection_id}/extractors | Get Extractor Performance
*AnalyticsCollectionsApi* | [**get_failure_analysis_analytics**](docs/AnalyticsCollectionsApi.md#get_failure_analysis_analytics) | **GET** /v1/analytics/collections/{collection_id}/failures | Get Failure Analysis
*AnalyticsCollectionsApi* | [**get_latency_metrics_analytics**](docs/AnalyticsCollectionsApi.md#get_latency_metrics_analytics) | **GET** /v1/analytics/collections/{collection_id}/latency | Get Latency Metrics
*AnalyticsExtractorsApi* | [**get_extractor_performance_analytics**](docs/AnalyticsExtractorsApi.md#get_extractor_performance_analytics) | **GET** /v1/analytics/extractors/performance | Get Extractor Performance
*AnalyticsIndexesApi* | [**get_field_usage_analytics_indexes**](docs/AnalyticsIndexesApi.md#get_field_usage_analytics_indexes) | **GET** /v1/analytics/indexes/usage | Get Field Usage
*AnalyticsIndexesApi* | [**get_index_suggestions_analytics_indexes**](docs/AnalyticsIndexesApi.md#get_index_suggestions_analytics_indexes) | **GET** /v1/analytics/indexes/suggestions | Get Index Suggestions
*AnalyticsInferenceApi* | [**get_inference_performance_analytics**](docs/AnalyticsInferenceApi.md#get_inference_performance_analytics) | **GET** /v1/analytics/inference/performance | Get Inference Performance
*AnalyticsNamespacesApi* | [**get_compound_index_patterns_analytics_namespaces_indexes**](docs/AnalyticsNamespacesApi.md#get_compound_index_patterns_analytics_namespaces_indexes) | **GET** /v1/analytics/namespaces/indexes/compound-patterns | Get Compound Index Patterns
*AnalyticsNamespacesApi* | [**get_field_performance_analytics_namespaces**](docs/AnalyticsNamespacesApi.md#get_field_performance_analytics_namespaces) | **GET** /v1/analytics/namespaces/fields/performance | Get Field Performance
*AnalyticsNamespacesApi* | [**get_index_recommendations_analytics_namespaces_indexes**](docs/AnalyticsNamespacesApi.md#get_index_recommendations_analytics_namespaces_indexes) | **GET** /v1/analytics/namespaces/indexes/recommendations | Get Index Recommendations
*AnalyticsNamespacesApi* | [**get_most_queried_fields_analytics_namespaces**](docs/AnalyticsNamespacesApi.md#get_most_queried_fields_analytics_namespaces) | **GET** /v1/analytics/namespaces/fields/most-queried | Get Most Queried Fields
*AnalyticsNamespacesApi* | [**get_namespace_summary_analytics**](docs/AnalyticsNamespacesApi.md#get_namespace_summary_analytics) | **GET** /v1/analytics/namespaces/summary | Get Namespace Summary
*AnalyticsNamespacesApi* | [**get_slow_queries_analytics_namespaces**](docs/AnalyticsNamespacesApi.md#get_slow_queries_analytics_namespaces) | **GET** /v1/analytics/namespaces/queries/slow | Get Slow Queries
*AnalyticsPerformanceApi* | [**analyze_bottlenecks_analytics_performance_engine**](docs/AnalyticsPerformanceApi.md#analyze_bottlenecks_analytics_performance_engine) | **GET** /v1/analytics/performance/engine/bottlenecks | Analyze Bottlenecks
*AnalyticsPerformanceApi* | [**get_batch_diagnostics_analytics_performance_batches**](docs/AnalyticsPerformanceApi.md#get_batch_diagnostics_analytics_performance_batches) | **GET** /v1/analytics/performance/batches/{batch_id}/diagnostics | Get Batch Diagnostics
*AnalyticsPerformanceApi* | [**get_engine_performance_analytics**](docs/AnalyticsPerformanceApi.md#get_engine_performance_analytics) | **GET** /v1/analytics/performance/engine | Get Engine Performance
*AnalyticsPerformanceApi* | [**get_engine_stage_breakdown_analytics_performance**](docs/AnalyticsPerformanceApi.md#get_engine_stage_breakdown_analytics_performance) | **GET** /v1/analytics/performance/engine/stages | Get Engine Stage Breakdown
*AnalyticsPerformanceApi* | [**get_extractor_breakdown_analytics_performance_engine**](docs/AnalyticsPerformanceApi.md#get_extractor_breakdown_analytics_performance_engine) | **GET** /v1/analytics/performance/engine/extractors | Get Extractor Breakdown
*AnalyticsPerformanceApi* | [**get_slowest_operations_analytics_performance_engine_slow**](docs/AnalyticsPerformanceApi.md#get_slowest_operations_analytics_performance_engine_slow) | **GET** /v1/analytics/performance/engine/slow-operations | Get Slowest Operations
*AnalyticsRetrieversApi* | [**analyze_for_tuning_analytics_retrievers**](docs/AnalyticsRetrieversApi.md#analyze_for_tuning_analytics_retrievers) | **POST** /v1/analytics/retrievers/{retriever_id}/analyze-tuning | Analyze For Tuning
*AnalyticsRetrieversApi* | [**get_cache_performance_analytics_retrievers**](docs/AnalyticsRetrieversApi.md#get_cache_performance_analytics_retrievers) | **GET** /v1/analytics/retrievers/{retriever_id}/cache-performance | Get Cache Performance
*AnalyticsRetrieversApi* | [**get_retriever_performance_analytics**](docs/AnalyticsRetrieversApi.md#get_retriever_performance_analytics) | **GET** /v1/analytics/retrievers/{retriever_id}/performance | Get Retriever Performance
*AnalyticsRetrieversApi* | [**get_retriever_signals_analytics**](docs/AnalyticsRetrieversApi.md#get_retriever_signals_analytics) | **GET** /v1/analytics/retrievers/{retriever_id}/signals | Get Retriever Signals
*AnalyticsRetrieversApi* | [**get_slowest_queries_analytics_retrievers_id_slow**](docs/AnalyticsRetrieversApi.md#get_slowest_queries_analytics_retrievers_id_slow) | **GET** /v1/analytics/retrievers/{retriever_id}/slow-queries | Get Slowest Queries
*AnalyticsRetrieversApi* | [**get_stage_breakdown_analytics_retrievers**](docs/AnalyticsRetrieversApi.md#get_stage_breakdown_analytics_retrievers) | **GET** /v1/analytics/retrievers/{retriever_id}/stages | Get Stage Breakdown
*AnalyticsTaxonomiesApi* | [**get_assignment_metrics_analytics_taxonomies_taxonomy**](docs/AnalyticsTaxonomiesApi.md#get_assignment_metrics_analytics_taxonomies_taxonomy) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/assignments | Get Assignment Metrics
*AnalyticsTaxonomiesApi* | [**get_confidence_distribution_analytics_taxonomies_taxonomy**](docs/AnalyticsTaxonomiesApi.md#get_confidence_distribution_analytics_taxonomies_taxonomy) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/confidence | Get Confidence Distribution
*AnalyticsTaxonomiesApi* | [**get_enrichment_history_analytics_taxonomies_taxonomy**](docs/AnalyticsTaxonomiesApi.md#get_enrichment_history_analytics_taxonomies_taxonomy) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/enrichments | Get Enrichment History
*AnalyticsTaxonomiesApi* | [**get_label_distribution_analytics_taxonomies_taxonomy**](docs/AnalyticsTaxonomiesApi.md#get_label_distribution_analytics_taxonomies_taxonomy) | **GET** /v1/analytics/taxonomies/{taxonomy_id}/labels | Get Label Distribution
*AnalyticsUsageApi* | [**get_usage_summary_analytics**](docs/AnalyticsUsageApi.md#get_usage_summary_analytics) | **GET** /v1/analytics/usage/summary | Get Usage Summary
*BucketBatchesApi* | [**add_objects_to_batch_buckets_batches**](docs/BucketBatchesApi.md#add_objects_to_batch_buckets_batches) | **POST** /v1/buckets/{bucket_identifier}/batches/{batch_id}/objects | Add Objects to Batch
*BucketBatchesApi* | [**cancel_batch_buckets_batches**](docs/BucketBatchesApi.md#cancel_batch_buckets_batches) | **POST** /v1/buckets/{bucket_identifier}/batches/{batch_id}/cancel | Cancel Batch
*BucketBatchesApi* | [**create_batch_buckets_batches**](docs/BucketBatchesApi.md#create_batch_buckets_batches) | **POST** /v1/buckets/{bucket_identifier}/batches | Create Batch
*BucketBatchesApi* | [**delete_batch_buckets_batches**](docs/BucketBatchesApi.md#delete_batch_buckets_batches) | **DELETE** /v1/buckets/{bucket_identifier}/batches/{batch_id} | Delete Batch
*BucketBatchesApi* | [**get_batch_buckets_batches**](docs/BucketBatchesApi.md#get_batch_buckets_batches) | **GET** /v1/buckets/{bucket_identifier}/batches/{batch_id} | Get Batch Configuration
*BucketBatchesApi* | [**get_batch_logs_buckets_batches**](docs/BucketBatchesApi.md#get_batch_logs_buckets_batches) | **GET** /v1/buckets/{bucket_identifier}/batches/{batch_id}/logs | Get Ray Job Logs for Batch
*BucketBatchesApi* | [**get_failed_documents_buckets_batches_batch**](docs/BucketBatchesApi.md#get_failed_documents_buckets_batches_batch) | **GET** /v1/buckets/{bucket_identifier}/batches/{batch_id}/failed-documents | Get Failed Documents for Batch
*BucketBatchesApi* | [**list_batches_buckets**](docs/BucketBatchesApi.md#list_batches_buckets) | **POST** /v1/buckets/{bucket_identifier}/batches/list | List Batches
*BucketBatchesApi* | [**patch_batch_buckets_batches**](docs/BucketBatchesApi.md#patch_batch_buckets_batches) | **PATCH** /v1/buckets/{bucket_identifier}/batches/{batch_id} | Partially Update Batch
*BucketBatchesApi* | [**retry_batch_buckets_batches**](docs/BucketBatchesApi.md#retry_batch_buckets_batches) | **POST** /v1/buckets/{bucket_identifier}/batches/{batch_id}/retry | Retry Failed Documents
*BucketBatchesApi* | [**retry_qdrant_write_buckets_batches_batch_id_tiers_num**](docs/BucketBatchesApi.md#retry_qdrant_write_buckets_batches_batch_id_tiers_num) | **POST** /v1/buckets/{bucket_identifier}/batches/{batch_id}/tiers/{tier_num}/retry-qdrant-write | Retry Qdrant Write from S3
*BucketBatchesApi* | [**submit_batch_buckets_batches**](docs/BucketBatchesApi.md#submit_batch_buckets_batches) | **POST** /v1/buckets/{bucket_identifier}/batches/{batch_id}/submit | Submit Batch for Processing
*BucketObjectsApi* | [**aggregate_objects_buckets**](docs/BucketObjectsApi.md#aggregate_objects_buckets) | **POST** /v1/buckets/{bucket_identifier}/objects/aggregate | Aggregate Objects
*BucketObjectsApi* | [**create_object_buckets**](docs/BucketObjectsApi.md#create_object_buckets) | **POST** /v1/buckets/{bucket_identifier}/objects | Create Object
*BucketObjectsApi* | [**create_objects_batch_buckets**](docs/BucketObjectsApi.md#create_objects_batch_buckets) | **POST** /v1/buckets/{bucket_identifier}/objects/batch | Create Objects in Batch
*BucketObjectsApi* | [**delete_object_buckets**](docs/BucketObjectsApi.md#delete_object_buckets) | **DELETE** /v1/buckets/{bucket_identifier}/objects/{object_identifier} | Delete Object
*BucketObjectsApi* | [**get_object_buckets**](docs/BucketObjectsApi.md#get_object_buckets) | **GET** /v1/buckets/{bucket_identifier}/objects/{object_identifier} | Get Object
*BucketObjectsApi* | [**list_objects_buckets**](docs/BucketObjectsApi.md#list_objects_buckets) | **POST** /v1/buckets/{bucket_identifier}/objects/list | List Objects
*BucketObjectsApi* | [**patch_object_buckets**](docs/BucketObjectsApi.md#patch_object_buckets) | **PATCH** /v1/buckets/{bucket_identifier}/objects/{object_identifier} | Partially Update Object
*BucketObjectsApi* | [**update_object_buckets**](docs/BucketObjectsApi.md#update_object_buckets) | **PUT** /v1/buckets/{bucket_identifier}/objects/{object_identifier} | Update Object
*BucketSyncsApi* | [**create_sync_configuration_buckets**](docs/BucketSyncsApi.md#create_sync_configuration_buckets) | **POST** /v1/buckets/{bucket_id}/syncs | Create Sync Configuration
*BucketSyncsApi* | [**delete_sync_configuration_buckets_id_config**](docs/BucketSyncsApi.md#delete_sync_configuration_buckets_id_config) | **DELETE** /v1/buckets/{bucket_id}/syncs/{sync_config_id} | Delete Sync Configuration
*BucketSyncsApi* | [**get_sync_configuration_buckets_id_config**](docs/BucketSyncsApi.md#get_sync_configuration_buckets_id_config) | **GET** /v1/buckets/{bucket_id}/syncs/{sync_config_id} | Get Sync Configuration
*BucketSyncsApi* | [**list_sync_configurations_buckets**](docs/BucketSyncsApi.md#list_sync_configurations_buckets) | **POST** /v1/buckets/{bucket_id}/syncs/list | List Sync Configurations
*BucketSyncsApi* | [**pause_sync_configuration_buckets_id_config**](docs/BucketSyncsApi.md#pause_sync_configuration_buckets_id_config) | **POST** /v1/buckets/{bucket_id}/syncs/{sync_config_id}/pause | Pause Sync Configuration
*BucketSyncsApi* | [**resume_sync_configuration_buckets_id_config**](docs/BucketSyncsApi.md#resume_sync_configuration_buckets_id_config) | **POST** /v1/buckets/{bucket_id}/syncs/{sync_config_id}/resume | Resume Sync Configuration
*BucketSyncsApi* | [**trigger_sync_configuration_buckets_id_config**](docs/BucketSyncsApi.md#trigger_sync_configuration_buckets_id_config) | **POST** /v1/buckets/{bucket_id}/syncs/{sync_config_id}/trigger | Trigger Sync Configuration
*BucketSyncsApi* | [**update_sync_configuration_buckets_id_config**](docs/BucketSyncsApi.md#update_sync_configuration_buckets_id_config) | **PATCH** /v1/buckets/{bucket_id}/syncs/{sync_config_id} | Update Sync Configuration
*BucketTemplatesApi* | [**create_bucket_template_from**](docs/BucketTemplatesApi.md#create_bucket_template_from) | **POST** /v1/templates/buckets/from-bucket/{bucket_id} | Create Bucket Template
*BucketTemplatesApi* | [**get_bucket_template**](docs/BucketTemplatesApi.md#get_bucket_template) | **GET** /v1/templates/buckets/{template_id} | Get Bucket Template
*BucketTemplatesApi* | [**instantiate_bucket_template**](docs/BucketTemplatesApi.md#instantiate_bucket_template) | **POST** /v1/templates/buckets/{template_id}/instantiate | Instantiate Bucket Template
*BucketTemplatesApi* | [**list_bucket_templates**](docs/BucketTemplatesApi.md#list_bucket_templates) | **POST** /v1/templates/buckets | List Bucket Templates
*BucketUploadsApi* | [**confirm_upload_buckets**](docs/BucketUploadsApi.md#confirm_upload_buckets) | **POST** /v1/buckets/{bucket_identifier}/uploads/{upload_id}/confirm | Confirm Upload
*BucketUploadsApi* | [**confirm_uploads_batch_buckets**](docs/BucketUploadsApi.md#confirm_uploads_batch_buckets) | **POST** /v1/buckets/{bucket_identifier}/uploads/confirm/batch | Batch Confirm Uploads
*BucketUploadsApi* | [**create_upload_buckets**](docs/BucketUploadsApi.md#create_upload_buckets) | **POST** /v1/buckets/{bucket_identifier}/uploads | Create Upload
*BucketUploadsApi* | [**create_uploads_batch_buckets**](docs/BucketUploadsApi.md#create_uploads_batch_buckets) | **POST** /v1/buckets/{bucket_identifier}/uploads/batch | Batch Create Uploads
*BucketUploadsApi* | [**delete_upload_buckets**](docs/BucketUploadsApi.md#delete_upload_buckets) | **DELETE** /v1/buckets/{bucket_identifier}/uploads/{upload_id} | Delete Upload
*BucketUploadsApi* | [**get_upload_buckets**](docs/BucketUploadsApi.md#get_upload_buckets) | **GET** /v1/buckets/{bucket_identifier}/uploads/{upload_id} | Get Upload
*BucketUploadsApi* | [**list_uploads_buckets**](docs/BucketUploadsApi.md#list_uploads_buckets) | **POST** /v1/buckets/{bucket_identifier}/uploads/list | List Uploads
*BucketsApi* | [**create_bucket**](docs/BucketsApi.md#create_bucket) | **POST** /v1/buckets | Create Bucket
*BucketsApi* | [**delete_bucket**](docs/BucketsApi.md#delete_bucket) | **DELETE** /v1/buckets/{bucket_identifier} | Delete Bucket
*BucketsApi* | [**get_bucket**](docs/BucketsApi.md#get_bucket) | **GET** /v1/buckets/{bucket_identifier} | Get Bucket
*BucketsApi* | [**list_buckets**](docs/BucketsApi.md#list_buckets) | **POST** /v1/buckets/list | List Buckets
*BucketsApi* | [**patch_bucket**](docs/BucketsApi.md#patch_bucket) | **PATCH** /v1/buckets/{bucket_identifier} | Partially Update Bucket
*BucketsApi* | [**update_bucket**](docs/BucketsApi.md#update_bucket) | **PUT** /v1/buckets/{bucket_identifier} | Update Bucket
*ClusterExecutionsApi* | [**cancel_execution_clusters_id_run**](docs/ClusterExecutionsApi.md#cancel_execution_clusters_id_run) | **POST** /v1/clusters/{cluster_id}/executions/{run_id}/cancel | Cancel Execution
*ClusterExecutionsApi* | [**get_cluster_execution**](docs/ClusterExecutionsApi.md#get_cluster_execution) | **GET** /v1/clusters/{cluster_id}/executions | Get Latest Cluster Execution
*ClusterExecutionsApi* | [**get_cluster_execution_by_run**](docs/ClusterExecutionsApi.md#get_cluster_execution_by_run) | **GET** /v1/clusters/{cluster_id}/executions/{run_id} | Get Specific Cluster Execution
*ClusterExecutionsApi* | [**list_cluster_executions**](docs/ClusterExecutionsApi.md#list_cluster_executions) | **POST** /v1/clusters/{cluster_id}/executions/list | List Cluster Execution History
*ClusterTemplatesApi* | [**create_cluster_template_from**](docs/ClusterTemplatesApi.md#create_cluster_template_from) | **POST** /v1/templates/clusters/from-cluster/{cluster_id} | Create Cluster Template
*ClusterTemplatesApi* | [**get_cluster_template**](docs/ClusterTemplatesApi.md#get_cluster_template) | **GET** /v1/templates/clusters/{template_id} | Get Cluster Template
*ClusterTemplatesApi* | [**instantiate_cluster_template**](docs/ClusterTemplatesApi.md#instantiate_cluster_template) | **POST** /v1/templates/clusters/{template_id}/instantiate | Instantiate Cluster Template
*ClusterTemplatesApi* | [**list_cluster_templates**](docs/ClusterTemplatesApi.md#list_cluster_templates) | **POST** /v1/templates/clusters | List Cluster Templates
*ClusterTriggersApi* | [**create_trigger_clusters**](docs/ClusterTriggersApi.md#create_trigger_clusters) | **POST** /v1/clusters/triggers | Create Cluster Trigger
*ClusterTriggersApi* | [**delete_trigger_clusters**](docs/ClusterTriggersApi.md#delete_trigger_clusters) | **DELETE** /v1/clusters/triggers/{trigger_id} | Delete Cluster Trigger
*ClusterTriggersApi* | [**get_trigger_clusters**](docs/ClusterTriggersApi.md#get_trigger_clusters) | **GET** /v1/clusters/triggers/{trigger_id} | Get Cluster Trigger
*ClusterTriggersApi* | [**get_trigger_history_clusters**](docs/ClusterTriggersApi.md#get_trigger_history_clusters) | **POST** /v1/clusters/triggers/{trigger_id}/history | Get Trigger Execution History
*ClusterTriggersApi* | [**list_triggers_clusters**](docs/ClusterTriggersApi.md#list_triggers_clusters) | **POST** /v1/clusters/triggers/list | List Cluster Triggers
*ClusterTriggersApi* | [**pause_trigger_clusters**](docs/ClusterTriggersApi.md#pause_trigger_clusters) | **POST** /v1/clusters/triggers/{trigger_id}/pause | Pause Cluster Trigger
*ClusterTriggersApi* | [**resume_trigger_clusters**](docs/ClusterTriggersApi.md#resume_trigger_clusters) | **POST** /v1/clusters/triggers/{trigger_id}/resume | Resume Cluster Trigger
*ClusterTriggersApi* | [**update_trigger_clusters**](docs/ClusterTriggersApi.md#update_trigger_clusters) | **PATCH** /v1/clusters/triggers/{trigger_id} | Update Cluster Trigger
*ClustersApi* | [**apply_cluster_enrichment_enrich**](docs/ClustersApi.md#apply_cluster_enrichment_enrich) | **POST** /v1/clusters/enrich | Apply Cluster Enrichment
*ClustersApi* | [**create_cluster**](docs/ClustersApi.md#create_cluster) | **POST** /v1/clusters | Create Cluster
*ClustersApi* | [**delete_cluster**](docs/ClustersApi.md#delete_cluster) | **DELETE** /v1/clusters/{cluster_id} | Delete Cluster
*ClustersApi* | [**execute_clustering_clusters**](docs/ClustersApi.md#execute_clustering_clusters) | **POST** /v1/clusters/{cluster_id}/execute | Execute Clustering
*ClustersApi* | [**get_cluster**](docs/ClustersApi.md#get_cluster) | **GET** /v1/clusters/{cluster_identifier} | Get Cluster
*ClustersApi* | [**list_clusters**](docs/ClustersApi.md#list_clusters) | **POST** /v1/clusters/list | List Clusters
*ClustersApi* | [**patch_cluster**](docs/ClustersApi.md#patch_cluster) | **PATCH** /v1/clusters/{cluster_identifier} | Partially Update Cluster
*CollectionDocumentsApi* | [**aggregate_documents**](docs/CollectionDocumentsApi.md#aggregate_documents) | **POST** /v1/collections/{collection_identifier}/documents/aggregate | Aggregate Documents
*CollectionDocumentsApi* | [**batch_delete**](docs/CollectionDocumentsApi.md#batch_delete) | **DELETE** /v1/collections/{collection_identifier}/documents/batch | Batch Delete Documents
*CollectionDocumentsApi* | [**batch_update**](docs/CollectionDocumentsApi.md#batch_update) | **POST** /v1/collections/{collection_identifier}/documents/batch | Batch Update Documents
*CollectionDocumentsApi* | [**bulk_update**](docs/CollectionDocumentsApi.md#bulk_update) | **PATCH** /v1/collections/{collection_identifier}/documents/bulk | Bulk Update Documents
*CollectionDocumentsApi* | [**create_document**](docs/CollectionDocumentsApi.md#create_document) | **POST** /v1/collections/{collection_identifier}/documents | Create a document.
*CollectionDocumentsApi* | [**delete_document**](docs/CollectionDocumentsApi.md#delete_document) | **DELETE** /v1/collections/{collection_identifier}/documents/{document_id} | Delete a document by ID.
*CollectionDocumentsApi* | [**get_document**](docs/CollectionDocumentsApi.md#get_document) | **GET** /v1/collections/{collection_identifier}/documents/{document_id} | Get a document by ID.
*CollectionDocumentsApi* | [**list_documents**](docs/CollectionDocumentsApi.md#list_documents) | **POST** /v1/collections/{collection_identifier}/documents/list | List documents.
*CollectionDocumentsApi* | [**patch_document**](docs/CollectionDocumentsApi.md#patch_document) | **PATCH** /v1/collections/{collection_identifier}/documents/{document_id} | Patch Document
*CollectionDocumentsApi* | [**update_document**](docs/CollectionDocumentsApi.md#update_document) | **PUT** /v1/collections/{collection_identifier}/documents/{document_id} | Update Document
*CollectionSchemaApi* | [**sync_collection_schema**](docs/CollectionSchemaApi.md#sync_collection_schema) | **POST** /v1/collections/{collection_id}/sync-schema | Sync Collection Schema
*CollectionTaxonomiesApi* | [**apply_taxonomy_to_collection**](docs/CollectionTaxonomiesApi.md#apply_taxonomy_to_collection) | **POST** /v1/collections/{collection_identifier}/apply-taxonomy | Apply Taxonomy to Existing Documents
*CollectionTemplatesApi* | [**create_collection_template_from**](docs/CollectionTemplatesApi.md#create_collection_template_from) | **POST** /v1/templates/collections/from-collection/{collection_id} | Create Collection Template
*CollectionTemplatesApi* | [**get_collection_template**](docs/CollectionTemplatesApi.md#get_collection_template) | **GET** /v1/templates/collections/{template_id} | Get Collection Template
*CollectionTemplatesApi* | [**instantiate_collection_template**](docs/CollectionTemplatesApi.md#instantiate_collection_template) | **POST** /v1/templates/collections/{template_id}/instantiate | Instantiate Collection Template
*CollectionTemplatesApi* | [**list_collection_templates**](docs/CollectionTemplatesApi.md#list_collection_templates) | **POST** /v1/templates/collections | List Collection Templates
*CollectionsApi* | [**clone_collection**](docs/CollectionsApi.md#clone_collection) | **POST** /v1/collections/{collection_identifier}/clone | Clone Collection
*CollectionsApi* | [**create_collection**](docs/CollectionsApi.md#create_collection) | **POST** /v1/collections | Create Collection
*CollectionsApi* | [**delete_collection**](docs/CollectionsApi.md#delete_collection) | **DELETE** /v1/collections/{collection_identifier} | Delete Collection
*CollectionsApi* | [**describe_collection_features**](docs/CollectionsApi.md#describe_collection_features) | **GET** /v1/collections/{collection_identifier}/features | Describe collection features
*CollectionsApi* | [**export_collection**](docs/CollectionsApi.md#export_collection) | **POST** /v1/collections/{collection_identifier}/export | Export Collection
*CollectionsApi* | [**get_collection**](docs/CollectionsApi.md#get_collection) | **GET** /v1/collections/{collection_identifier} | Get Collection
*CollectionsApi* | [**list_collections**](docs/CollectionsApi.md#list_collections) | **POST** /v1/collections/list | List Collections
*CollectionsApi* | [**trigger_collection**](docs/CollectionsApi.md#trigger_collection) | **POST** /v1/collections/{collection_identifier}/trigger | Trigger Collection Processing
*CollectionsApi* | [**update_collection**](docs/CollectionsApi.md#update_collection) | **PATCH** /v1/collections/{collection_identifier} | Update Collection
*CustomModelsApi* | [**delete_model_namespaces**](docs/CustomModelsApi.md#delete_model_namespaces) | **DELETE** /v1/namespaces/{namespace_id}/models/{model_id} | Delete a model
*CustomModelsApi* | [**deploy_model_namespaces**](docs/CustomModelsApi.md#deploy_model_namespaces) | **POST** /v1/namespaces/{namespace_id}/models/{model_id}/deploy | Deploy model to Ray object store
*CustomModelsApi* | [**disable_org_model_namespaces**](docs/CustomModelsApi.md#disable_org_model_namespaces) | **POST** /v1/namespaces/{namespace_id}/models/org/{model_id}/disable | Disable org model for namespace
*CustomModelsApi* | [**enable_org_model_namespaces**](docs/CustomModelsApi.md#enable_org_model_namespaces) | **POST** /v1/namespaces/{namespace_id}/models/org/{model_id}/enable | Enable org model for namespace
*CustomModelsApi* | [**get_model_namespaces**](docs/CustomModelsApi.md#get_model_namespaces) | **GET** /v1/namespaces/{namespace_id}/models/{model_id} | Get model details
*CustomModelsApi* | [**list_available_org_models_namespaces**](docs/CustomModelsApi.md#list_available_org_models_namespaces) | **GET** /v1/namespaces/{namespace_id}/models/available | List available org models
*CustomModelsApi* | [**list_models_namespaces**](docs/CustomModelsApi.md#list_models_namespaces) | **GET** /v1/namespaces/{namespace_id}/models | List models in namespace
*CustomModelsApi* | [**upload_model_namespaces**](docs/CustomModelsApi.md#upload_model_namespaces) | **POST** /v1/namespaces/{namespace_id}/models | Upload a custom model
*CustomPluginsNamespaceApi* | [**confirm_upload_namespaces_id_plugins**](docs/CustomPluginsNamespaceApi.md#confirm_upload_namespaces_id_plugins) | **POST** /v1/namespaces/{namespace_id}/plugins/uploads/{upload_id}/confirm | Confirm plugin upload
*CustomPluginsNamespaceApi* | [**delete_plugin_namespaces**](docs/CustomPluginsNamespaceApi.md#delete_plugin_namespaces) | **DELETE** /v1/namespaces/{namespace_id}/plugins/{plugin_id} | Delete a plugin
*CustomPluginsNamespaceApi* | [**deploy_plugin_namespaces**](docs/CustomPluginsNamespaceApi.md#deploy_plugin_namespaces) | **POST** /v1/namespaces/{namespace_id}/plugins/{plugin_id}/deploy | Deploy or redeploy a plugin
*CustomPluginsNamespaceApi* | [**disable_org_plugin_namespaces**](docs/CustomPluginsNamespaceApi.md#disable_org_plugin_namespaces) | **POST** /v1/namespaces/{namespace_id}/plugins/org/{plugin_id}/disable | Disable org plugin for namespace
*CustomPluginsNamespaceApi* | [**enable_org_plugin_namespaces**](docs/CustomPluginsNamespaceApi.md#enable_org_plugin_namespaces) | **POST** /v1/namespaces/{namespace_id}/plugins/org/{plugin_id}/enable | Enable org plugin for namespace
*CustomPluginsNamespaceApi* | [**generate_upload_url_namespaces_id_plugins**](docs/CustomPluginsNamespaceApi.md#generate_upload_url_namespaces_id_plugins) | **POST** /v1/namespaces/{namespace_id}/plugins/uploads | Generate presigned URL for plugin upload
*CustomPluginsNamespaceApi* | [**get_deployment_status_namespaces_id_plugins**](docs/CustomPluginsNamespaceApi.md#get_deployment_status_namespaces_id_plugins) | **GET** /v1/namespaces/{namespace_id}/plugins/{plugin_id}/status | Get plugin deployment status
*CustomPluginsNamespaceApi* | [**get_plugin_namespaces**](docs/CustomPluginsNamespaceApi.md#get_plugin_namespaces) | **GET** /v1/namespaces/{namespace_id}/plugins/{plugin_id} | Get plugin details
*CustomPluginsNamespaceApi* | [**list_available_org_plugins_namespaces**](docs/CustomPluginsNamespaceApi.md#list_available_org_plugins_namespaces) | **GET** /v1/namespaces/{namespace_id}/plugins/available | List available org plugins
*CustomPluginsNamespaceApi* | [**list_plugins_namespaces**](docs/CustomPluginsNamespaceApi.md#list_plugins_namespaces) | **GET** /v1/namespaces/{namespace_id}/plugins | List plugins in namespace
*CustomPluginsNamespaceApi* | [**undeploy_plugin_namespaces**](docs/CustomPluginsNamespaceApi.md#undeploy_plugin_namespaces) | **POST** /v1/namespaces/{namespace_id}/plugins/{plugin_id}/undeploy | Undeploy a plugin
*CustomPluginsNamespaceApi* | [**upload_plugin_namespaces**](docs/CustomPluginsNamespaceApi.md#upload_plugin_namespaces) | **POST** /v1/namespaces/{namespace_id}/plugins | Upload a custom plugin
*DocumentLineageApi* | [**get_decomposition_tree_objects**](docs/DocumentLineageApi.md#get_decomposition_tree_objects) | **GET** /v1/objects/{object_id}/decomposition-tree | Get decomposition tree visualization
*DocumentLineageApi* | [**get_document_lineage**](docs/DocumentLineageApi.md#get_document_lineage) | **GET** /v1/collections/{collection_id}/documents/{document_id}/lineage | Get document lineage
*DocumentLineageApi* | [**get_documents_by_object**](docs/DocumentLineageApi.md#get_documents_by_object) | **GET** /v1/objects/{object_id}/documents | Get all documents derived from an object
*EvaluationDatasetsApi* | [**create_dataset_retrievers_evaluations**](docs/EvaluationDatasetsApi.md#create_dataset_retrievers_evaluations) | **POST** /v1/retrievers/evaluations/datasets | Create evaluation dataset
*EvaluationDatasetsApi* | [**get_dataset_retrievers_evaluations**](docs/EvaluationDatasetsApi.md#get_dataset_retrievers_evaluations) | **GET** /v1/retrievers/evaluations/datasets/{dataset_identifier} | Get evaluation dataset
*EvaluationDatasetsApi* | [**list_datasets_retrievers_evaluations**](docs/EvaluationDatasetsApi.md#list_datasets_retrievers_evaluations) | **GET** /v1/retrievers/evaluations/datasets | List evaluation datasets
*EvaluationsApi* | [**get_evaluation_retrievers**](docs/EvaluationsApi.md#get_evaluation_retrievers) | **GET** /v1/retrievers/{retriever_id}/evaluations/{evaluation_id} | Get evaluation results
*EvaluationsApi* | [**list_evaluations_retrievers**](docs/EvaluationsApi.md#list_evaluations_retrievers) | **GET** /v1/retrievers/{retriever_id}/evaluations | List evaluations
*EvaluationsApi* | [**start_evaluation_retrievers**](docs/EvaluationsApi.md#start_evaluation_retrievers) | **POST** /v1/retrievers/{retriever_id}/evaluations | Run evaluation
*FeatureExtractorsApi* | [**get_feature_extractor_by**](docs/FeatureExtractorsApi.md#get_feature_extractor_by) | **GET** /v1/collections/features/extractors/{feature_extractor_id} | Get Feature Extractor by Name
*FeatureExtractorsApi* | [**list_feature_extractors**](docs/FeatureExtractorsApi.md#list_feature_extractors) | **GET** /v1/collections/features/extractors | List Feature Extractors
*HealthApi* | [**healthcheck_health**](docs/HealthApi.md#healthcheck_health) | **GET** /v1/health | Healthcheck
*HealthApi* | [**healthcheck_health_0**](docs/HealthApi.md#healthcheck_health_0) | **GET** /v1/health | Healthcheck
*HealthApi* | [**liveness_health**](docs/HealthApi.md#liveness_health) | **GET** /v1/health/liveness | Liveness
*HealthApi* | [**liveness_health_0**](docs/HealthApi.md#liveness_health_0) | **GET** /v1/health/liveness | Liveness
*InferenceApi* | [**execute_raw_inference**](docs/InferenceApi.md#execute_raw_inference) | **POST** /v1/inference | Execute Raw Inference
*ManifestApi* | [**apply_manifest**](docs/ManifestApi.md#apply_manifest) | **POST** /v1/manifest/apply | Apply Manifest
*ManifestApi* | [**diff_manifest**](docs/ManifestApi.md#diff_manifest) | **POST** /v1/manifest/diff | Diff Manifest
*ManifestApi* | [**export_manifest_get**](docs/ManifestApi.md#export_manifest_get) | **GET** /v1/manifest/export | Export Manifest Get
*ManifestApi* | [**export_manifest_post**](docs/ManifestApi.md#export_manifest_post) | **POST** /v1/manifest/export | Export Manifest Post
*ManifestApi* | [**generate_manifest**](docs/ManifestApi.md#generate_manifest) | **POST** /v1/manifest/generate | Generate Manifest
*ManifestApi* | [**validate_manifest**](docs/ManifestApi.md#validate_manifest) | **POST** /v1/manifest/validate | Validate Manifest
*ModelsApi* | [**confirm_upload_models**](docs/ModelsApi.md#confirm_upload_models) | **POST** /v1/models/uploads/{upload_id}/confirm | Confirm model upload
*ModelsApi* | [**delete_model**](docs/ModelsApi.md#delete_model) | **DELETE** /v1/models/{model_id} | Delete model
*ModelsApi* | [**generate_upload_url_models**](docs/ModelsApi.md#generate_upload_url_models) | **POST** /v1/models/uploads | Generate presigned URL for model upload
*ModelsApi* | [**get_model**](docs/ModelsApi.md#get_model) | **GET** /v1/models/{model_id} | Get model details
*ModelsApi* | [**list_models**](docs/ModelsApi.md#list_models) | **GET** /v1/models | List organization models
*NamespaceCloneApi* | [**clone_namespace**](docs/NamespaceCloneApi.md#clone_namespace) | **POST** /v1/namespaces/{namespace_identifier}/clone | Clone Namespace
*NamespaceExtractorsApi* | [**get_extractor_namespaces**](docs/NamespaceExtractorsApi.md#get_extractor_namespaces) | **GET** /v1/namespaces/{namespace_id}/extractors/{extractor_id} | Get extractor details
*NamespaceExtractorsApi* | [**list_extractors_namespaces**](docs/NamespaceExtractorsApi.md#list_extractors_namespaces) | **GET** /v1/namespaces/{namespace_id}/extractors | List all extractors available to namespace
*NamespaceMigrationsApi* | [**cancel_migration_namespaces**](docs/NamespaceMigrationsApi.md#cancel_migration_namespaces) | **POST** /v1/namespaces/migrations/{migration_id}/cancel | Cancel Migration
*NamespaceMigrationsApi* | [**create_migration_namespaces**](docs/NamespaceMigrationsApi.md#create_migration_namespaces) | **POST** /v1/namespaces/migrations/ | Create Migration
*NamespaceMigrationsApi* | [**delete_migration_namespaces**](docs/NamespaceMigrationsApi.md#delete_migration_namespaces) | **DELETE** /v1/namespaces/migrations/{migration_id} | Delete Migration
*NamespaceMigrationsApi* | [**get_migration_namespaces**](docs/NamespaceMigrationsApi.md#get_migration_namespaces) | **GET** /v1/namespaces/migrations/{migration_id} | Get Migration
*NamespaceMigrationsApi* | [**list_migrations_namespaces**](docs/NamespaceMigrationsApi.md#list_migrations_namespaces) | **POST** /v1/namespaces/migrations/list | List Migrations
*NamespaceMigrationsApi* | [**start_migration_namespaces**](docs/NamespaceMigrationsApi.md#start_migration_namespaces) | **POST** /v1/namespaces/migrations/{migration_id}/start | Start Migration
*NamespaceMigrationsApi* | [**validate_migration_namespaces**](docs/NamespaceMigrationsApi.md#validate_migration_namespaces) | **POST** /v1/namespaces/migrations/validate | Validate Migration
*NamespaceTemplatesApi* | [**create_namespace_template_from**](docs/NamespaceTemplatesApi.md#create_namespace_template_from) | **POST** /v1/templates/namespaces/from-namespace/{namespace_id} | Create Namespace Template
*NamespaceTemplatesApi* | [**get_namespace_template**](docs/NamespaceTemplatesApi.md#get_namespace_template) | **GET** /v1/templates/namespaces/{template_id} | Get Namespace Template
*NamespaceTemplatesApi* | [**instantiate_namespace_template**](docs/NamespaceTemplatesApi.md#instantiate_namespace_template) | **POST** /v1/templates/namespaces/{template_id}/instantiate | Instantiate Namespace Template
*NamespaceTemplatesApi* | [**list_namespace_templates**](docs/NamespaceTemplatesApi.md#list_namespace_templates) | **GET** /v1/templates/namespaces | List Namespace Templates
*NamespacesApi* | [**create_namespace**](docs/NamespacesApi.md#create_namespace) | **POST** /v1/namespaces | Create Namespace
*NamespacesApi* | [**delete_namespace**](docs/NamespacesApi.md#delete_namespace) | **DELETE** /v1/namespaces/{namespace_identifier} | Delete Namespace
*NamespacesApi* | [**get_namespace**](docs/NamespacesApi.md#get_namespace) | **GET** /v1/namespaces/{namespace_identifier} | Get Namespace
*NamespacesApi* | [**list_namespaces**](docs/NamespacesApi.md#list_namespaces) | **POST** /v1/namespaces/list | List Namespaces
*NamespacesApi* | [**patch_namespace**](docs/NamespacesApi.md#patch_namespace) | **PATCH** /v1/namespaces/{namespace_identifier} | Partially Update Namespace
*NamespacesApi* | [**update_namespace**](docs/NamespacesApi.md#update_namespace) | **PUT** /v1/namespaces/{namespace_identifier} | Update Namespace
*NotificationsApi* | [**delete_notification**](docs/NotificationsApi.md#delete_notification) | **DELETE** /v1/notifications/{notification_id} | Delete Notification
*NotificationsApi* | [**get_funnel_state_notifications**](docs/NotificationsApi.md#get_funnel_state_notifications) | **GET** /v1/notifications/funnel/state | Get Funnel State
*NotificationsApi* | [**get_notification**](docs/NotificationsApi.md#get_notification) | **GET** /v1/notifications/{notification_id} | Get Notification
*NotificationsApi* | [**get_preferences_notifications**](docs/NotificationsApi.md#get_preferences_notifications) | **GET** /v1/notifications/preferences | Get Preferences
*NotificationsApi* | [**get_reminder_preferences_notifications**](docs/NotificationsApi.md#get_reminder_preferences_notifications) | **GET** /v1/notifications/preferences/reminders | Get Reminder Preferences
*NotificationsApi* | [**get_unread_count_notifications**](docs/NotificationsApi.md#get_unread_count_notifications) | **GET** /v1/notifications/unread/count | Get Unread Count
*NotificationsApi* | [**list_notifications**](docs/NotificationsApi.md#list_notifications) | **POST** /v1/notifications/list | List Notifications
*NotificationsApi* | [**mark_all_as_read_notifications**](docs/NotificationsApi.md#mark_all_as_read_notifications) | **POST** /v1/notifications/read/all | Mark All As Read
*NotificationsApi* | [**mark_as_read_notifications**](docs/NotificationsApi.md#mark_as_read_notifications) | **POST** /v1/notifications/{notification_id}/read | Mark As Read
*NotificationsApi* | [**update_preferences_notifications**](docs/NotificationsApi.md#update_preferences_notifications) | **PUT** /v1/notifications/preferences | Update Preferences
*NotificationsApi* | [**update_reminder_preferences_notifications**](docs/NotificationsApi.md#update_reminder_preferences_notifications) | **PUT** /v1/notifications/preferences/reminders | Update Reminder Preferences
*OrganizationAPIKeysApi* | [**create_key_organizations_users_email**](docs/OrganizationAPIKeysApi.md#create_key_organizations_users_email) | **POST** /v1/organizations/users/{user_email}/api-keys | Create Api Key
*OrganizationAPIKeysApi* | [**delete_key_organizations_users_email_name**](docs/OrganizationAPIKeysApi.md#delete_key_organizations_users_email_name) | **DELETE** /v1/organizations/users/{user_email}/api-keys/{key_name} | Delete Api Key
*OrganizationAPIKeysApi* | [**list_keys_organizations_users_email**](docs/OrganizationAPIKeysApi.md#list_keys_organizations_users_email) | **GET** /v1/organizations/users/{user_email}/api-keys | List Api Keys
*OrganizationAPIKeysApi* | [**rotate_key_organizations_users_email_name**](docs/OrganizationAPIKeysApi.md#rotate_key_organizations_users_email_name) | **POST** /v1/organizations/users/{user_email}/api-keys/{key_name}/rotate | Rotate Api Key
*OrganizationAPIKeysApi* | [**update_key_organizations_users_email_name**](docs/OrganizationAPIKeysApi.md#update_key_organizations_users_email_name) | **PATCH** /v1/organizations/users/{user_email}/api-keys/{key_name} | Update Api Key
*OrganizationAuditApi* | [**get_audit_log_organizations**](docs/OrganizationAuditApi.md#get_audit_log_organizations) | **GET** /v1/organizations/audit/logs/{audit_id} | Get Audit Log
*OrganizationAuditApi* | [**get_audit_settings_organizations**](docs/OrganizationAuditApi.md#get_audit_settings_organizations) | **GET** /v1/organizations/audit/settings | Get Audit Settings
*OrganizationAuditApi* | [**list_audit_logs_organizations**](docs/OrganizationAuditApi.md#list_audit_logs_organizations) | **GET** /v1/organizations/audit/logs | List Audit Logs
*OrganizationAuditApi* | [**update_audit_settings_organizations**](docs/OrganizationAuditApi.md#update_audit_settings_organizations) | **PATCH** /v1/organizations/audit/settings | Update Audit Settings
*OrganizationBillingApi* | [**confirm_payment_method_organizations_billing**](docs/OrganizationBillingApi.md#confirm_payment_method_organizations_billing) | **POST** /v1/organizations/billing/confirm-payment-method | Confirm Payment Method
*OrganizationBillingApi* | [**disable_auto_billing_organizations**](docs/OrganizationBillingApi.md#disable_auto_billing_organizations) | **POST** /v1/organizations/billing/disable-auto-billing | Disable Auto Billing
*OrganizationBillingApi* | [**enable_auto_billing_organizations**](docs/OrganizationBillingApi.md#enable_auto_billing_organizations) | **POST** /v1/organizations/billing/enable-auto-billing | Enable Auto Billing
*OrganizationBillingApi* | [**get_credit_balance_organizations_billing**](docs/OrganizationBillingApi.md#get_credit_balance_organizations_billing) | **GET** /v1/organizations/billing/balance | Get Credit Balance
*OrganizationBillingApi* | [**get_current_usage_organizations_billing**](docs/OrganizationBillingApi.md#get_current_usage_organizations_billing) | **GET** /v1/organizations/billing/usage/current | Get Current Usage
*OrganizationBillingApi* | [**get_payment_method_organizations_billing**](docs/OrganizationBillingApi.md#get_payment_method_organizations_billing) | **GET** /v1/organizations/billing/payment-method | Get Payment Method
*OrganizationBillingApi* | [**get_spending_caps_organizations_billing**](docs/OrganizationBillingApi.md#get_spending_caps_organizations_billing) | **GET** /v1/organizations/billing/spending-caps | Get Spending Caps
*OrganizationBillingApi* | [**get_usage_breakdown_organizations_billing**](docs/OrganizationBillingApi.md#get_usage_breakdown_organizations_billing) | **GET** /v1/organizations/billing/usage/breakdown | Get Usage Breakdown
*OrganizationBillingApi* | [**list_invoices_organizations_billing**](docs/OrganizationBillingApi.md#list_invoices_organizations_billing) | **GET** /v1/organizations/billing/invoices | List Invoices
*OrganizationBillingApi* | [**setup_payment_method_organizations_billing**](docs/OrganizationBillingApi.md#setup_payment_method_organizations_billing) | **POST** /v1/organizations/billing/setup-payment-method | Setup Payment Method
*OrganizationBillingApi* | [**update_spending_caps_organizations_billing**](docs/OrganizationBillingApi.md#update_spending_caps_organizations_billing) | **POST** /v1/organizations/billing/spending-caps | Update Spending Caps
*OrganizationConnectionsApi* | [**create_storage_connection_organizations**](docs/OrganizationConnectionsApi.md#create_storage_connection_organizations) | **POST** /v1/organizations/connections | Create Storage Connection
*OrganizationConnectionsApi* | [**delete_storage_connection_organizations**](docs/OrganizationConnectionsApi.md#delete_storage_connection_organizations) | **DELETE** /v1/organizations/connections/{connection_identifier} | Delete Storage Connection
*OrganizationConnectionsApi* | [**get_storage_connection_organizations**](docs/OrganizationConnectionsApi.md#get_storage_connection_organizations) | **GET** /v1/organizations/connections/{connection_identifier} | Get Storage Connection
*OrganizationConnectionsApi* | [**list_google_drive_files_organizations_connections**](docs/OrganizationConnectionsApi.md#list_google_drive_files_organizations_connections) | **GET** /v1/organizations/connections/{connection_identifier}/files | List Google Drive Files
*OrganizationConnectionsApi* | [**list_google_drive_folders_organizations_connections**](docs/OrganizationConnectionsApi.md#list_google_drive_folders_organizations_connections) | **GET** /v1/organizations/connections/{connection_identifier}/folders | List Google Drive Folders
*OrganizationConnectionsApi* | [**list_storage_connections_organizations**](docs/OrganizationConnectionsApi.md#list_storage_connections_organizations) | **POST** /v1/organizations/connections/list | List Storage Connections
*OrganizationConnectionsApi* | [**test_storage_connection_organizations**](docs/OrganizationConnectionsApi.md#test_storage_connection_organizations) | **POST** /v1/organizations/connections/{connection_identifier}/test | Test Storage Connection
*OrganizationConnectionsApi* | [**update_storage_connection_organizations**](docs/OrganizationConnectionsApi.md#update_storage_connection_organizations) | **PATCH** /v1/organizations/connections/{connection_identifier} | Update Storage Connection
*OrganizationSecretsApi* | [**create_secret_organizations**](docs/OrganizationSecretsApi.md#create_secret_organizations) | **POST** /v1/organizations/secrets | Create Secret
*OrganizationSecretsApi* | [**delete_secret_organizations_name**](docs/OrganizationSecretsApi.md#delete_secret_organizations_name) | **DELETE** /v1/organizations/secrets/{secret_name} | Delete Secret
*OrganizationSecretsApi* | [**list_secrets_organizations**](docs/OrganizationSecretsApi.md#list_secrets_organizations) | **GET** /v1/organizations/secrets | List Secrets
*OrganizationSecretsApi* | [**update_secret_organizations_name**](docs/OrganizationSecretsApi.md#update_secret_organizations_name) | **PUT** /v1/organizations/secrets/{secret_name} | Update Secret
*OrganizationUsageApi* | [**get_key_breakdown_organizations_id_usage_endpoints**](docs/OrganizationUsageApi.md#get_key_breakdown_organizations_id_usage_endpoints) | **GET** /v1/organizations/api-keys/{key_id}/usage/endpoints | Get Api Key Endpoint Breakdown
*OrganizationUsageApi* | [**get_key_usage_organizations**](docs/OrganizationUsageApi.md#get_key_usage_organizations) | **GET** /v1/organizations/api-keys/{key_id}/usage | Get Api Key Usage
*OrganizationUsageApi* | [**get_org_usage_organizations**](docs/OrganizationUsageApi.md#get_org_usage_organizations) | **GET** /v1/organizations/usage | Get Org Usage
*OrganizationUsersApi* | [**create_user_organizations**](docs/OrganizationUsersApi.md#create_user_organizations) | **POST** /v1/organizations/users | Create User
*OrganizationUsersApi* | [**delete_user_organizations_email**](docs/OrganizationUsersApi.md#delete_user_organizations_email) | **DELETE** /v1/organizations/users/{user_email} | Delete User
*OrganizationUsersApi* | [**get_user_organizations_email**](docs/OrganizationUsersApi.md#get_user_organizations_email) | **GET** /v1/organizations/users/{user_email} | Get User
*OrganizationUsersApi* | [**list_users_organizations**](docs/OrganizationUsersApi.md#list_users_organizations) | **GET** /v1/organizations/users | List Users
*OrganizationUsersApi* | [**update_user_organizations_email**](docs/OrganizationUsersApi.md#update_user_organizations_email) | **PATCH** /v1/organizations/users/{user_email} | Update User
*OrganizationsApi* | [**add_credits_organizations**](docs/OrganizationsApi.md#add_credits_organizations) | **POST** /v1/organizations/credits | Add Credits
*OrganizationsApi* | [**get_organization**](docs/OrganizationsApi.md#get_organization) | **GET** /v1/organizations | Get Organization
*OrganizationsApi* | [**update_organization**](docs/OrganizationsApi.md#update_organization) | **PATCH** /v1/organizations | Update Organization
*PluginsApi* | [**confirm_upload_plugins**](docs/PluginsApi.md#confirm_upload_plugins) | **POST** /v1/plugins/uploads/{upload_id}/confirm | Confirm plugin upload
*PluginsApi* | [**delete_plugin**](docs/PluginsApi.md#delete_plugin) | **DELETE** /v1/plugins/{plugin_id} | Delete a plugin
*PluginsApi* | [**generate_upload_url_plugins**](docs/PluginsApi.md#generate_upload_url_plugins) | **POST** /v1/plugins/uploads | Generate presigned URL for plugin upload
*PluginsApi* | [**get_plugin**](docs/PluginsApi.md#get_plugin) | **GET** /v1/plugins/{plugin_id} | Get plugin details
*PluginsApi* | [**list_plugins**](docs/PluginsApi.md#list_plugins) | **GET** /v1/plugins | List plugins in organization
*PrivateApi* | [**add_user_to_organization**](docs/PrivateApi.md#add_user_to_organization) | **POST** /v1/private/organizations/add-user | Add User To Organization Private
*PrivateApi* | [**complete_tier_internal_batches_batch_id_num**](docs/PrivateApi.md#complete_tier_internal_batches_batch_id_num) | **POST** /v1/internal/batches/{batch_id}/tiers/{tier_num}/complete | Mark tier complete and trigger next tier (KISS - Engine callback)
*PrivateApi* | [**configure_storage_cors_configurations**](docs/PrivateApi.md#configure_storage_cors_configurations) | **POST** /v1/private/configurations/storage/cors | Configure CORS for Object Storage
*PrivateApi* | [**create_bootstrap_key_organizations_id_users_email**](docs/PrivateApi.md#create_bootstrap_key_organizations_id_users_email) | **POST** /v1/private/organizations/{organization_id}/users/{user_email}/bootstrap-key | Create Bootstrap Api Key
*PrivateApi* | [**create_organization**](docs/PrivateApi.md#create_organization) | **POST** /v1/private/organizations | Create Organization Private
*PrivateApi* | [**delete_organization**](docs/PrivateApi.md#delete_organization) | **DELETE** /v1/private/organizations/{organization_identifier} | Delete Organization Private
*PrivateApi* | [**diagnose_clickhouse_configurations_diagnostics**](docs/PrivateApi.md#diagnose_clickhouse_configurations_diagnostics) | **GET** /v1/private/configurations/clickhouse/diagnostics | Diagnose ClickHouse Configuration
*PrivateApi* | [**get_organization**](docs/PrivateApi.md#get_organization) | **GET** /v1/private/organizations/{organization_identifier} | Get Organization Private
*PrivateApi* | [**get_storage_cors_configurations**](docs/PrivateApi.md#get_storage_cors_configurations) | **GET** /v1/private/configurations/storage/cors | Get Current CORS Configuration
*PrivateApi* | [**update_organization**](docs/PrivateApi.md#update_organization) | **PATCH** /v1/private/organizations/{organization_identifier} | Update Organization Private
*PrivateApi* | [**update_task_status_internal**](docs/PrivateApi.md#update_task_status_internal) | **POST** /v1/internal/tasks/{task_id}/status | Update task status (Engine callback)
*PublicNotificationsAPIApi* | [**unsubscribe_from_nudges_notifications**](docs/PublicNotificationsAPIApi.md#unsubscribe_from_nudges_notifications) | **GET** /v1/public/notifications/unsubscribe | Unsubscribe From Nudges
*PublicRetrieverAPIApi* | [**execute_retriever_name**](docs/PublicRetrieverAPIApi.md#execute_retriever_name) | **POST** /v1/public/retrievers/{public_name}/execute | Execute Public Retriever
*PublicRetrieverAPIApi* | [**get_retriever_config_name**](docs/PublicRetrieverAPIApi.md#get_retriever_config_name) | **GET** /v1/public/retrievers/{public_name}/config | Get Public Retriever Config
*PublicRetrieverAPIApi* | [**get_retriever_template_name**](docs/PublicRetrieverAPIApi.md#get_retriever_template_name) | **GET** /v1/public/retrievers/{public_name}/template | Get Public Retriever Template
*PublicRetrieverAPIApi* | [**list_retrievers**](docs/PublicRetrieverAPIApi.md#list_retrievers) | **GET** /v1/public/retrievers/ | List Public Retrievers
*PublicRetrieverAPIApi* | [**track_interaction_batch_retrievers_name**](docs/PublicRetrieverAPIApi.md#track_interaction_batch_retrievers_name) | **POST** /v1/public/retrievers/{public_name}/interactions/batch | Track Interaction Batch
*PublicRetrieverAPIApi* | [**track_interaction_retrievers_name**](docs/PublicRetrieverAPIApi.md#track_interaction_retrievers_name) | **POST** /v1/public/retrievers/{public_name}/interactions | Track Interaction
*PublicRetrieverAPIApi* | [**verify_password_retrievers_name**](docs/PublicRetrieverAPIApi.md#verify_password_retrievers_name) | **POST** /v1/public/retrievers/{public_name}/verify | Verify Password
*PublicScaffoldsApi* | [**get_scaffold_templates**](docs/PublicScaffoldsApi.md#get_scaffold_templates) | **GET** /v1/public/templates/scaffolds/{template_id} | Get Scaffold
*PublicScaffoldsApi* | [**list_scaffolds_templates**](docs/PublicScaffoldsApi.md#list_scaffolds_templates) | **GET** /v1/public/templates/scaffolds | List Scaffolds
*PublicTemplatesAPIApi* | [**get_namespace_template**](docs/PublicTemplatesAPIApi.md#get_namespace_template) | **GET** /v1/public/templates/namespaces/{template_id} | Get Public Namespace Template
*PublicTemplatesAPIApi* | [**get_retriever_template**](docs/PublicTemplatesAPIApi.md#get_retriever_template) | **GET** /v1/public/templates/retrievers/{template_id} | Get Public Retriever Template
*PublicTemplatesAPIApi* | [**get_scaffold_templates**](docs/PublicTemplatesAPIApi.md#get_scaffold_templates) | **GET** /v1/public/templates/scaffolds/{template_id} | Get Scaffold
*PublicTemplatesAPIApi* | [**list_namespace_templates**](docs/PublicTemplatesAPIApi.md#list_namespace_templates) | **GET** /v1/public/templates/namespaces | List Public Namespace Templates
*PublicTemplatesAPIApi* | [**list_retriever_templates**](docs/PublicTemplatesAPIApi.md#list_retriever_templates) | **GET** /v1/public/templates/retrievers | List Public Retriever Templates
*PublicTemplatesAPIApi* | [**list_scaffolds_templates**](docs/PublicTemplatesAPIApi.md#list_scaffolds_templates) | **GET** /v1/public/templates/scaffolds | List Scaffolds
*PublishedRetrieversApi* | [**check_name_availability_retrievers_id_publish**](docs/PublishedRetrieversApi.md#check_name_availability_retrievers_id_publish) | **GET** /v1/retrievers/{retriever_id}/publish/availability | Check Name Availability
*PublishedRetrieversApi* | [**get_organization_publish_stats_retrievers**](docs/PublishedRetrieversApi.md#get_organization_publish_stats_retrievers) | **GET** /v1/retrievers/publish/stats | Get Organization Publish Stats
*PublishedRetrieversApi* | [**get_published_retriever_id_publish**](docs/PublishedRetrieversApi.md#get_published_retriever_id_publish) | **GET** /v1/retrievers/{retriever_id}/publish | Get Published Retriever
*PublishedRetrieversApi* | [**list_published_retrievers**](docs/PublishedRetrieversApi.md#list_published_retrievers) | **GET** /v1/retrievers/published | List Published Retrievers
*PublishedRetrieversApi* | [**publish_retriever**](docs/PublishedRetrieversApi.md#publish_retriever) | **POST** /v1/retrievers/{retriever_id}/publish | Publish Retriever
*PublishedRetrieversApi* | [**unpublish_retriever_id_publish**](docs/PublishedRetrieversApi.md#unpublish_retriever_id_publish) | **DELETE** /v1/retrievers/{retriever_id}/publish | Unpublish Retriever
*PublishedRetrieversApi* | [**update_published_retriever_id_publish**](docs/PublishedRetrieversApi.md#update_published_retriever_id_publish) | **PATCH** /v1/retrievers/{retriever_id}/publish | Update Published Retriever
*ResourceSearchApi* | [**search_resources**](docs/ResourceSearchApi.md#search_resources) | **POST** /v1/resources/search | Search Resources
*RetrieverBenchmarksApi* | [**create_benchmark_retrievers**](docs/RetrieverBenchmarksApi.md#create_benchmark_retrievers) | **POST** /v1/retrievers/benchmarks | Create benchmark
*RetrieverBenchmarksApi* | [**create_benchmark_retrievers_0**](docs/RetrieverBenchmarksApi.md#create_benchmark_retrievers_0) | **POST** /v1/retrievers/benchmarks | Create benchmark
*RetrieverBenchmarksApi* | [**delete_benchmark_retrievers**](docs/RetrieverBenchmarksApi.md#delete_benchmark_retrievers) | **DELETE** /v1/retrievers/benchmarks/{benchmark_id} | Delete benchmark
*RetrieverBenchmarksApi* | [**delete_benchmark_retrievers_0**](docs/RetrieverBenchmarksApi.md#delete_benchmark_retrievers_0) | **DELETE** /v1/retrievers/benchmarks/{benchmark_id} | Delete benchmark
*RetrieverBenchmarksApi* | [**get_benchmark_retrievers**](docs/RetrieverBenchmarksApi.md#get_benchmark_retrievers) | **GET** /v1/retrievers/benchmarks/{benchmark_id} | Get benchmark
*RetrieverBenchmarksApi* | [**get_benchmark_retrievers_0**](docs/RetrieverBenchmarksApi.md#get_benchmark_retrievers_0) | **GET** /v1/retrievers/benchmarks/{benchmark_id} | Get benchmark
*RetrieverBenchmarksApi* | [**list_benchmarks_retrievers**](docs/RetrieverBenchmarksApi.md#list_benchmarks_retrievers) | **GET** /v1/retrievers/benchmarks | List benchmarks
*RetrieverBenchmarksApi* | [**list_benchmarks_retrievers_0**](docs/RetrieverBenchmarksApi.md#list_benchmarks_retrievers_0) | **GET** /v1/retrievers/benchmarks | List benchmarks
*RetrieverEvaluationsApi* | [**create_dataset_retrievers_evaluations**](docs/RetrieverEvaluationsApi.md#create_dataset_retrievers_evaluations) | **POST** /v1/retrievers/evaluations/datasets | Create evaluation dataset
*RetrieverEvaluationsApi* | [**get_dataset_retrievers_evaluations**](docs/RetrieverEvaluationsApi.md#get_dataset_retrievers_evaluations) | **GET** /v1/retrievers/evaluations/datasets/{dataset_identifier} | Get evaluation dataset
*RetrieverEvaluationsApi* | [**get_evaluation_retrievers**](docs/RetrieverEvaluationsApi.md#get_evaluation_retrievers) | **GET** /v1/retrievers/{retriever_id}/evaluations/{evaluation_id} | Get evaluation results
*RetrieverEvaluationsApi* | [**list_datasets_retrievers_evaluations**](docs/RetrieverEvaluationsApi.md#list_datasets_retrievers_evaluations) | **GET** /v1/retrievers/evaluations/datasets | List evaluation datasets
*RetrieverEvaluationsApi* | [**list_evaluations_retrievers**](docs/RetrieverEvaluationsApi.md#list_evaluations_retrievers) | **GET** /v1/retrievers/{retriever_id}/evaluations | List evaluations
*RetrieverEvaluationsApi* | [**start_evaluation_retrievers**](docs/RetrieverEvaluationsApi.md#start_evaluation_retrievers) | **POST** /v1/retrievers/{retriever_id}/evaluations | Run evaluation
*RetrieverInteractionsApi* | [**create_interaction_retrievers**](docs/RetrieverInteractionsApi.md#create_interaction_retrievers) | **POST** /v1/retrievers/interactions | Create Interaction
*RetrieverInteractionsApi* | [**delete_interaction_retrievers**](docs/RetrieverInteractionsApi.md#delete_interaction_retrievers) | **DELETE** /v1/retrievers/interactions/{interaction_id} | Delete Interaction
*RetrieverInteractionsApi* | [**get_interaction_retrievers**](docs/RetrieverInteractionsApi.md#get_interaction_retrievers) | **GET** /v1/retrievers/interactions/{interaction_id} | Get Interaction
*RetrieverInteractionsApi* | [**list_interactions_retrievers**](docs/RetrieverInteractionsApi.md#list_interactions_retrievers) | **POST** /v1/retrievers/interactions/list | List Interactions
*RetrieverStagesApi* | [**list_stages_retrievers**](docs/RetrieverStagesApi.md#list_stages_retrievers) | **GET** /v1/retrievers/stages | List Available Retriever Stages
*RetrieverTemplatesApi* | [**create_retriever_template_from**](docs/RetrieverTemplatesApi.md#create_retriever_template_from) | **POST** /v1/templates/retrievers/from-retriever/{retriever_id} | Create Retriever Template
*RetrieverTemplatesApi* | [**get_retriever_template**](docs/RetrieverTemplatesApi.md#get_retriever_template) | **GET** /v1/templates/retrievers/{template_id} | Get Retriever Template
*RetrieverTemplatesApi* | [**instantiate_retriever_template**](docs/RetrieverTemplatesApi.md#instantiate_retriever_template) | **POST** /v1/templates/retrievers/{template_id}/instantiate | Instantiate Retriever Template
*RetrieverTemplatesApi* | [**list_retriever_templates**](docs/RetrieverTemplatesApi.md#list_retriever_templates) | **POST** /v1/templates/retrievers | List Retriever Templates
*RetrieversApi* | [**clone_retriever**](docs/RetrieversApi.md#clone_retriever) | **POST** /v1/retrievers/{retriever_id}/clone | Clone Retriever
*RetrieversApi* | [**create_retriever**](docs/RetrieversApi.md#create_retriever) | **POST** /v1/retrievers | Create Retriever
*RetrieversApi* | [**delete_retriever**](docs/RetrieversApi.md#delete_retriever) | **DELETE** /v1/retrievers/{retriever_id} | Delete Retriever
*RetrieversApi* | [**execute_retriever**](docs/RetrieversApi.md#execute_retriever) | **POST** /v1/retrievers/{retriever_id}/execute | Execute Retriever (Auto-Optimized)
*RetrieversApi* | [**explain_retriever_execution_id_execute**](docs/RetrieversApi.md#explain_retriever_execution_id_execute) | **POST** /v1/retrievers/{retriever_id}/execute/explain | Explain Retriever Execution Plan
*RetrieversApi* | [**get_execution_retrievers**](docs/RetrieversApi.md#get_execution_retrievers) | **GET** /v1/retrievers/{retriever_id}/executions/{execution_id} | Get Execution
*RetrieversApi* | [**get_retriever**](docs/RetrieversApi.md#get_retriever) | **GET** /v1/retrievers/{retriever_id} | Get Retriever
*RetrieversApi* | [**list_executions_retrievers**](docs/RetrieversApi.md#list_executions_retrievers) | **POST** /v1/retrievers/{retriever_id}/executions/list | List Executions
*RetrieversApi* | [**list_retrievers**](docs/RetrieversApi.md#list_retrievers) | **POST** /v1/retrievers/list | List Retrievers
*RetrieversApi* | [**patch_retriever**](docs/RetrieversApi.md#patch_retriever) | **PATCH** /v1/retrievers/{retriever_id} | Patch Retriever
*ScaffoldTemplatesApi* | [**instantiate_scaffold_template**](docs/ScaffoldTemplatesApi.md#instantiate_scaffold_template) | **POST** /v1/templates/scaffolds/{template_id}/instantiate | Instantiate Scaffold Template
*TasksApi* | [**get_task**](docs/TasksApi.md#get_task) | **GET** /v1/tasks/{task_id} | Get Task Information
*TasksApi* | [**kill_task**](docs/TasksApi.md#kill_task) | **DELETE** /v1/tasks/{task_id} | Kill Task
*TasksApi* | [**list_tasks**](docs/TasksApi.md#list_tasks) | **POST** /v1/tasks/list | List Tasks
*TaxonomiesApi* | [**clone_taxonomy_taxonomies**](docs/TaxonomiesApi.md#clone_taxonomy_taxonomies) | **POST** /v1/taxonomies/{taxonomy_identifier}/clone | Clone Taxonomy
*TaxonomiesApi* | [**create_taxonomy_taxonomies**](docs/TaxonomiesApi.md#create_taxonomy_taxonomies) | **POST** /v1/taxonomies | Create Taxonomy
*TaxonomiesApi* | [**create_taxonomy_version_taxonomies**](docs/TaxonomiesApi.md#create_taxonomy_version_taxonomies) | **POST** /v1/taxonomies/{taxonomy_id}/versions | Create Taxonomy Version
*TaxonomiesApi* | [**delete_taxonomy_taxonomies**](docs/TaxonomiesApi.md#delete_taxonomy_taxonomies) | **DELETE** /v1/taxonomies/{taxonomy_identifier} | Delete Taxonomy
*TaxonomiesApi* | [**execute_taxonomy_taxonomies**](docs/TaxonomiesApi.md#execute_taxonomy_taxonomies) | **POST** /v1/taxonomies/execute/{taxonomy_identifier} | Test taxonomy configuration (validation only)
*TaxonomiesApi* | [**get_taxonomy_taxonomies**](docs/TaxonomiesApi.md#get_taxonomy_taxonomies) | **GET** /v1/taxonomies/{taxonomy_identifier} | Get Taxonomy
*TaxonomiesApi* | [**list_taxonomies**](docs/TaxonomiesApi.md#list_taxonomies) | **POST** /v1/taxonomies/list | List Taxonomies
*TaxonomiesApi* | [**list_taxonomy_versions_taxonomies**](docs/TaxonomiesApi.md#list_taxonomy_versions_taxonomies) | **GET** /v1/taxonomies/{taxonomy_id}/versions | List Taxonomy Versions
*TaxonomiesApi* | [**patch_taxonomy_taxonomies**](docs/TaxonomiesApi.md#patch_taxonomy_taxonomies) | **PATCH** /v1/taxonomies/{taxonomy_identifier} | Partially Update Taxonomy
*TaxonomyAnalyticsApi* | [**analyze_transition_paths_taxonomies_taxonomy_id_analytics**](docs/TaxonomyAnalyticsApi.md#analyze_transition_paths_taxonomies_taxonomy_id_analytics) | **POST** /v1/taxonomies/{taxonomy_id}/analytics/paths | Analyze multi-step transition paths
*TaxonomyAnalyticsApi* | [**analyze_transition_paths_taxonomies_taxonomy_id_analytics_0**](docs/TaxonomyAnalyticsApi.md#analyze_transition_paths_taxonomies_taxonomy_id_analytics_0) | **POST** /v1/taxonomies/{taxonomy_id}/analytics/paths | Analyze multi-step transition paths
*TaxonomyAnalyticsApi* | [**compute_step_transitions_taxonomies_taxonomy_id_analytics**](docs/TaxonomyAnalyticsApi.md#compute_step_transitions_taxonomies_taxonomy_id_analytics) | **POST** /v1/taxonomies/{taxonomy_id}/analytics/transitions | Compute step transition analytics
*TaxonomyAnalyticsApi* | [**compute_step_transitions_taxonomies_taxonomy_id_analytics_0**](docs/TaxonomyAnalyticsApi.md#compute_step_transitions_taxonomies_taxonomy_id_analytics_0) | **POST** /v1/taxonomies/{taxonomy_id}/analytics/transitions | Compute step transition analytics
*TaxonomyAnalyticsApi* | [**get_available_steps_taxonomies_taxonomy_id_analytics**](docs/TaxonomyAnalyticsApi.md#get_available_steps_taxonomies_taxonomy_id_analytics) | **GET** /v1/taxonomies/{taxonomy_id}/analytics/available-steps | Get Available Steps
*TaxonomyAnalyticsApi* | [**get_available_steps_taxonomies_taxonomy_id_analytics_0**](docs/TaxonomyAnalyticsApi.md#get_available_steps_taxonomies_taxonomy_id_analytics_0) | **GET** /v1/taxonomies/{taxonomy_id}/analytics/available-steps | Get Available Steps
*TaxonomyTemplatesApi* | [**create_taxonomy_template_taxonomies_from**](docs/TaxonomyTemplatesApi.md#create_taxonomy_template_taxonomies_from) | **POST** /v1/templates/taxonomies/from-taxonomy/{taxonomy_id} | Create Taxonomy Template
*TaxonomyTemplatesApi* | [**get_taxonomy_template_taxonomies**](docs/TaxonomyTemplatesApi.md#get_taxonomy_template_taxonomies) | **GET** /v1/templates/taxonomies/{template_id} | Get Taxonomy Template
*TaxonomyTemplatesApi* | [**instantiate_taxonomy_template_taxonomies**](docs/TaxonomyTemplatesApi.md#instantiate_taxonomy_template_taxonomies) | **POST** /v1/templates/taxonomies/{template_id}/instantiate | Instantiate Taxonomy Template
*TaxonomyTemplatesApi* | [**list_taxonomy_templates_taxonomies**](docs/TaxonomyTemplatesApi.md#list_taxonomy_templates_taxonomies) | **POST** /v1/templates/taxonomies | List Taxonomy Templates
*TemplatesApi* | [**create_bucket_template_from**](docs/TemplatesApi.md#create_bucket_template_from) | **POST** /v1/templates/buckets/from-bucket/{bucket_id} | Create Bucket Template
*TemplatesApi* | [**create_cluster_template_from**](docs/TemplatesApi.md#create_cluster_template_from) | **POST** /v1/templates/clusters/from-cluster/{cluster_id} | Create Cluster Template
*TemplatesApi* | [**create_collection_template_from**](docs/TemplatesApi.md#create_collection_template_from) | **POST** /v1/templates/collections/from-collection/{collection_id} | Create Collection Template
*TemplatesApi* | [**create_namespace_template_from**](docs/TemplatesApi.md#create_namespace_template_from) | **POST** /v1/templates/namespaces/from-namespace/{namespace_id} | Create Namespace Template
*TemplatesApi* | [**create_retriever_template_from**](docs/TemplatesApi.md#create_retriever_template_from) | **POST** /v1/templates/retrievers/from-retriever/{retriever_id} | Create Retriever Template
*TemplatesApi* | [**create_taxonomy_template_taxonomies_from**](docs/TemplatesApi.md#create_taxonomy_template_taxonomies_from) | **POST** /v1/templates/taxonomies/from-taxonomy/{taxonomy_id} | Create Taxonomy Template
*TemplatesApi* | [**get_bucket_template**](docs/TemplatesApi.md#get_bucket_template) | **GET** /v1/templates/buckets/{template_id} | Get Bucket Template
*TemplatesApi* | [**get_cluster_template**](docs/TemplatesApi.md#get_cluster_template) | **GET** /v1/templates/clusters/{template_id} | Get Cluster Template
*TemplatesApi* | [**get_collection_template**](docs/TemplatesApi.md#get_collection_template) | **GET** /v1/templates/collections/{template_id} | Get Collection Template
*TemplatesApi* | [**get_namespace_template**](docs/TemplatesApi.md#get_namespace_template) | **GET** /v1/templates/namespaces/{template_id} | Get Namespace Template
*TemplatesApi* | [**get_retriever_template**](docs/TemplatesApi.md#get_retriever_template) | **GET** /v1/templates/retrievers/{template_id} | Get Retriever Template
*TemplatesApi* | [**get_taxonomy_template_taxonomies**](docs/TemplatesApi.md#get_taxonomy_template_taxonomies) | **GET** /v1/templates/taxonomies/{template_id} | Get Taxonomy Template
*TemplatesApi* | [**instantiate_bucket_template**](docs/TemplatesApi.md#instantiate_bucket_template) | **POST** /v1/templates/buckets/{template_id}/instantiate | Instantiate Bucket Template
*TemplatesApi* | [**instantiate_cluster_template**](docs/TemplatesApi.md#instantiate_cluster_template) | **POST** /v1/templates/clusters/{template_id}/instantiate | Instantiate Cluster Template
*TemplatesApi* | [**instantiate_collection_template**](docs/TemplatesApi.md#instantiate_collection_template) | **POST** /v1/templates/collections/{template_id}/instantiate | Instantiate Collection Template
*TemplatesApi* | [**instantiate_namespace_template**](docs/TemplatesApi.md#instantiate_namespace_template) | **POST** /v1/templates/namespaces/{template_id}/instantiate | Instantiate Namespace Template
*TemplatesApi* | [**instantiate_retriever_template**](docs/TemplatesApi.md#instantiate_retriever_template) | **POST** /v1/templates/retrievers/{template_id}/instantiate | Instantiate Retriever Template
*TemplatesApi* | [**instantiate_taxonomy_template_taxonomies**](docs/TemplatesApi.md#instantiate_taxonomy_template_taxonomies) | **POST** /v1/templates/taxonomies/{template_id}/instantiate | Instantiate Taxonomy Template
*TemplatesApi* | [**list_bucket_templates**](docs/TemplatesApi.md#list_bucket_templates) | **POST** /v1/templates/buckets | List Bucket Templates
*TemplatesApi* | [**list_cluster_templates**](docs/TemplatesApi.md#list_cluster_templates) | **POST** /v1/templates/clusters | List Cluster Templates
*TemplatesApi* | [**list_collection_templates**](docs/TemplatesApi.md#list_collection_templates) | **POST** /v1/templates/collections | List Collection Templates
*TemplatesApi* | [**list_namespace_templates**](docs/TemplatesApi.md#list_namespace_templates) | **GET** /v1/templates/namespaces | List Namespace Templates
*TemplatesApi* | [**list_retriever_templates**](docs/TemplatesApi.md#list_retriever_templates) | **POST** /v1/templates/retrievers | List Retriever Templates
*TemplatesApi* | [**list_taxonomy_templates_taxonomies**](docs/TemplatesApi.md#list_taxonomy_templates_taxonomies) | **POST** /v1/templates/taxonomies | List Taxonomy Templates
*WebhooksApi* | [**create_webhook_organizations**](docs/WebhooksApi.md#create_webhook_organizations) | **POST** /v1/organizations/webhooks/ | Create Webhook
*WebhooksApi* | [**delete_webhook_organizations**](docs/WebhooksApi.md#delete_webhook_organizations) | **DELETE** /v1/organizations/webhooks/{identifier} | Delete Webhook
*WebhooksApi* | [**get_webhook_organizations**](docs/WebhooksApi.md#get_webhook_organizations) | **GET** /v1/organizations/webhooks/{identifier} | Get Webhook
*WebhooksApi* | [**list_webhooks_organizations**](docs/WebhooksApi.md#list_webhooks_organizations) | **POST** /v1/organizations/webhooks/list | List Webhooks
*WebhooksApi* | [**update_webhook_organizations**](docs/WebhooksApi.md#update_webhook_organizations) | **PUT** /v1/organizations/webhooks/{identifier} | Update Webhook
*DefaultApi* | [**create_trigger**](docs/DefaultApi.md#create_trigger) | **POST** /v1/triggers | Create Trigger
*DefaultApi* | [**delete_trigger**](docs/DefaultApi.md#delete_trigger) | **DELETE** /v1/triggers/{trigger_id} | Delete Trigger
*DefaultApi* | [**execute_trigger_now**](docs/DefaultApi.md#execute_trigger_now) | **POST** /v1/triggers/{trigger_id}/execute | Execute Trigger Now
*DefaultApi* | [**get_trigger**](docs/DefaultApi.md#get_trigger) | **GET** /v1/triggers/{trigger_id} | Get Trigger
*DefaultApi* | [**get_trigger_history**](docs/DefaultApi.md#get_trigger_history) | **GET** /v1/triggers/{trigger_id}/history | Get Trigger Execution History
*DefaultApi* | [**list_triggers**](docs/DefaultApi.md#list_triggers) | **POST** /v1/triggers/list | List Triggers
*DefaultApi* | [**pause_trigger**](docs/DefaultApi.md#pause_trigger) | **POST** /v1/triggers/{trigger_id}/pause | Pause Trigger
*DefaultApi* | [**resume_trigger**](docs/DefaultApi.md#resume_trigger) | **POST** /v1/triggers/{trigger_id}/resume | Resume Trigger
*DefaultApi* | [**update_trigger**](docs/DefaultApi.md#update_trigger) | **PATCH** /v1/triggers/{trigger_id} | Update Trigger


## Documentation For Models

 - [APIKeyCreateRequest](docs/APIKeyCreateRequest.md)
 - [APIKeyCreateResponse](docs/APIKeyCreateResponse.md)
 - [APIKeyModel](docs/APIKeyModel.md)
 - [APIKeyUpdateRequest](docs/APIKeyUpdateRequest.md)
 - [AccountTier](docs/AccountTier.md)
 - [AddCreditsRequest](docs/AddCreditsRequest.md)
 - [AddCreditsResponse](docs/AddCreditsResponse.md)
 - [AddObjectsToBatchRequest](docs/AddObjectsToBatchRequest.md)
 - [AddUserToOrganizationRequest](docs/AddUserToOrganizationRequest.md)
 - [AdhocExecuteRequest](docs/AdhocExecuteRequest.md)
 - [AdhocExecutionDetail](docs/AdhocExecutionDetail.md)
 - [AdhocExecutionSummary](docs/AdhocExecutionSummary.md)
 - [AgentConfig](docs/AgentConfig.md)
 - [AgglomerativeParams](docs/AgglomerativeParams.md)
 - [AggregationFunction](docs/AggregationFunction.md)
 - [AggregationOperation](docs/AggregationOperation.md)
 - [AggregationResult](docs/AggregationResult.md)
 - [AlertApplicationConfigInput](docs/AlertApplicationConfigInput.md)
 - [AlertApplicationConfigOutput](docs/AlertApplicationConfigOutput.md)
 - [AlertExecutionListResponse](docs/AlertExecutionListResponse.md)
 - [AlertExecutionMode](docs/AlertExecutionMode.md)
 - [AlertExecutionResult](docs/AlertExecutionResult.md)
 - [AlertInputMapping](docs/AlertInputMapping.md)
 - [AlertListStats](docs/AlertListStats.md)
 - [AlertMatchResult](docs/AlertMatchResult.md)
 - [AlertNotificationConfig](docs/AlertNotificationConfig.md)
 - [AlertResponse](docs/AlertResponse.md)
 - [AlgorithmParams](docs/AlgorithmParams.md)
 - [AlignmentMetrics](docs/AlignmentMetrics.md)
 - [AndInner](docs/AndInner.md)
 - [AndInner1](docs/AndInner1.md)
 - [AndInner2](docs/AndInner2.md)
 - [AnthropicModel](docs/AnthropicModel.md)
 - [ApiAnalyticsBucketsModelsTimeRange](docs/ApiAnalyticsBucketsModelsTimeRange.md)
 - [ApiAnalyticsClustersModelsFailureAnalysisResponse](docs/ApiAnalyticsClustersModelsFailureAnalysisResponse.md)
 - [ApiAnalyticsClustersModelsTimeRange](docs/ApiAnalyticsClustersModelsTimeRange.md)
 - [ApiAnalyticsCollectionsModelsFailureAnalysisResponse](docs/ApiAnalyticsCollectionsModelsFailureAnalysisResponse.md)
 - [ApiAnalyticsCollectionsModelsTimeRange](docs/ApiAnalyticsCollectionsModelsTimeRange.md)
 - [ApiAnalyticsModelsTimeRange](docs/ApiAnalyticsModelsTimeRange.md)
 - [ApiAnalyticsTaxonomiesModelsTimeRange](docs/ApiAnalyticsTaxonomiesModelsTimeRange.md)
 - [ApiNamespacesPluginsModelsCreatePluginUploadRequest](docs/ApiNamespacesPluginsModelsCreatePluginUploadRequest.md)
 - [ApiNamespacesPluginsModelsPluginDeleteResponse](docs/ApiNamespacesPluginsModelsPluginDeleteResponse.md)
 - [ApiNamespacesPluginsModelsPluginDetailResponse](docs/ApiNamespacesPluginsModelsPluginDetailResponse.md)
 - [ApiNamespacesPluginsModelsPluginDocument](docs/ApiNamespacesPluginsModelsPluginDocument.md)
 - [ApiNamespacesPluginsModelsPluginListResponse](docs/ApiNamespacesPluginsModelsPluginListResponse.md)
 - [ApiNamespacesPluginsModelsPluginManifestMetadata](docs/ApiNamespacesPluginsModelsPluginManifestMetadata.md)
 - [ApiNamespacesPluginsModelsPluginPresignedURLResponse](docs/ApiNamespacesPluginsModelsPluginPresignedURLResponse.md)
 - [ApiPluginsModelsCreatePluginUploadRequest](docs/ApiPluginsModelsCreatePluginUploadRequest.md)
 - [ApiPluginsModelsPluginDeleteResponse](docs/ApiPluginsModelsPluginDeleteResponse.md)
 - [ApiPluginsModelsPluginDetailResponse](docs/ApiPluginsModelsPluginDetailResponse.md)
 - [ApiPluginsModelsPluginDocument](docs/ApiPluginsModelsPluginDocument.md)
 - [ApiPluginsModelsPluginListResponse](docs/ApiPluginsModelsPluginListResponse.md)
 - [ApiPluginsModelsPluginManifestMetadata](docs/ApiPluginsModelsPluginManifestMetadata.md)
 - [ApiPluginsModelsPluginPresignedURLResponse](docs/ApiPluginsModelsPluginPresignedURLResponse.md)
 - [ApplyClusterEnrichmentRequest](docs/ApplyClusterEnrichmentRequest.md)
 - [ApplyResult](docs/ApplyResult.md)
 - [ApplyTaxonomyRequest](docs/ApplyTaxonomyRequest.md)
 - [ApplyTaxonomyResponse](docs/ApplyTaxonomyResponse.md)
 - [AssignmentMetric](docs/AssignmentMetric.md)
 - [AssignmentMetricsResponse](docs/AssignmentMetricsResponse.md)
 - [AttributeBasedConfig](docs/AttributeBasedConfig.md)
 - [AuditAction](docs/AuditAction.md)
 - [AuditEventListResponse](docs/AuditEventListResponse.md)
 - [AuditEventResponse](docs/AuditEventResponse.md)
 - [AuditSettings](docs/AuditSettings.md)
 - [AuditSettingsUpdateRequest](docs/AuditSettingsUpdateRequest.md)
 - [AuthConfig](docs/AuthConfig.md)
 - [AuthType](docs/AuthType.md)
 - [AutoBillingToggleResponse](docs/AutoBillingToggleResponse.md)
 - [AvailableOrgModelItem](docs/AvailableOrgModelItem.md)
 - [AvailableOrgModelsResponse](docs/AvailableOrgModelsResponse.md)
 - [AvailableOrgPluginItem](docs/AvailableOrgPluginItem.md)
 - [AvailableOrgPluginsResponse](docs/AvailableOrgPluginsResponse.md)
 - [AvailableStepsResponse](docs/AvailableStepsResponse.md)
 - [BaseFeatureExtractorModelInput](docs/BaseFeatureExtractorModelInput.md)
 - [BaseFeatureExtractorModelOutput](docs/BaseFeatureExtractorModelOutput.md)
 - [BaseRateLimits](docs/BaseRateLimits.md)
 - [BaseTemplateModel](docs/BaseTemplateModel.md)
 - [BatchConfirmRequest](docs/BatchConfirmRequest.md)
 - [BatchConfirmResponse](docs/BatchConfirmResponse.md)
 - [BatchDeleteDocumentsRequest](docs/BatchDeleteDocumentsRequest.md)
 - [BatchDeleteDocumentsResponse](docs/BatchDeleteDocumentsResponse.md)
 - [BatchDiagnostics](docs/BatchDiagnostics.md)
 - [BatchDocumentDeleteResult](docs/BatchDocumentDeleteResult.md)
 - [BatchDocumentUpdate](docs/BatchDocumentUpdate.md)
 - [BatchDocumentUpdateResult](docs/BatchDocumentUpdateResult.md)
 - [BatchErrorDetail](docs/BatchErrorDetail.md)
 - [BatchModel](docs/BatchModel.md)
 - [BatchOptions](docs/BatchOptions.md)
 - [BatchStatistics](docs/BatchStatistics.md)
 - [BatchType](docs/BatchType.md)
 - [BatchUpdateDocumentsRequest](docs/BatchUpdateDocumentsRequest.md)
 - [BatchUpdateDocumentsResponse](docs/BatchUpdateDocumentsResponse.md)
 - [BatchUploadRequest](docs/BatchUploadRequest.md)
 - [BatchUploadResponse](docs/BatchUploadResponse.md)
 - [BenchmarkComparison](docs/BenchmarkComparison.md)
 - [BenchmarkListResponse](docs/BenchmarkListResponse.md)
 - [BenchmarkResponse](docs/BenchmarkResponse.md)
 - [BenchmarkResult](docs/BenchmarkResult.md)
 - [BenchmarkStatus](docs/BenchmarkStatus.md)
 - [BlobDetails](docs/BlobDetails.md)
 - [BlobMappingEntry](docs/BlobMappingEntry.md)
 - [BlobModel](docs/BlobModel.md)
 - [BlobType](docs/BlobType.md)
 - [BlobURLRef](docs/BlobURLRef.md)
 - [BoolIndexParams](docs/BoolIndexParams.md)
 - [BottleneckAnalysis](docs/BottleneckAnalysis.md)
 - [BottleneckResponse](docs/BottleneckResponse.md)
 - [BucketCreateRequest](docs/BucketCreateRequest.md)
 - [BucketHealthResponse](docs/BucketHealthResponse.md)
 - [BucketListStats](docs/BucketListStats.md)
 - [BucketPatchRequest](docs/BucketPatchRequest.md)
 - [BucketResponse](docs/BucketResponse.md)
 - [BucketSchemaFieldInput](docs/BucketSchemaFieldInput.md)
 - [BucketSchemaFieldOutput](docs/BucketSchemaFieldOutput.md)
 - [BucketSchemaFieldType](docs/BucketSchemaFieldType.md)
 - [BucketSchemaInput](docs/BucketSchemaInput.md)
 - [BucketSchemaOutput](docs/BucketSchemaOutput.md)
 - [BucketStorageResponse](docs/BucketStorageResponse.md)
 - [BucketUpdateRequest](docs/BucketUpdateRequest.md)
 - [BucketUsageResponse](docs/BucketUsageResponse.md)
 - [BudgetLimits](docs/BudgetLimits.md)
 - [BulkUpdateDocumentsRequest](docs/BulkUpdateDocumentsRequest.md)
 - [BulkUpdateDocumentsResponse](docs/BulkUpdateDocumentsResponse.md)
 - [CORSConfigurationInfo](docs/CORSConfigurationInfo.md)
 - [CORSConfigurationResponse](docs/CORSConfigurationResponse.md)
 - [CacheConfig](docs/CacheConfig.md)
 - [CachePerformanceResponse](docs/CachePerformanceResponse.md)
 - [CacheStatistics](docs/CacheStatistics.md)
 - [CancelMigrationRequest](docs/CancelMigrationRequest.md)
 - [CancelMigrationResponse](docs/CancelMigrationResponse.md)
 - [ChunkStrategy](docs/ChunkStrategy.md)
 - [CitationConfig](docs/CitationConfig.md)
 - [ClarificationOption](docs/ClarificationOption.md)
 - [CloneCollectionRequest](docs/CloneCollectionRequest.md)
 - [CloneCollectionResponse](docs/CloneCollectionResponse.md)
 - [CloneNamespaceRequest](docs/CloneNamespaceRequest.md)
 - [CloneNamespaceResourcesConfig](docs/CloneNamespaceResourcesConfig.md)
 - [CloneNamespaceResponse](docs/CloneNamespaceResponse.md)
 - [CloneRetrieverRequest](docs/CloneRetrieverRequest.md)
 - [CloneRetrieverResponse](docs/CloneRetrieverResponse.md)
 - [CloneTaxonomyRequest](docs/CloneTaxonomyRequest.md)
 - [CloneTaxonomyResponse](docs/CloneTaxonomyResponse.md)
 - [ClonedResourceSummary](docs/ClonedResourceSummary.md)
 - [ClusterApplicationConfig](docs/ClusterApplicationConfig.md)
 - [ClusterExecutionCentroid](docs/ClusterExecutionCentroid.md)
 - [ClusterExecutionListStats](docs/ClusterExecutionListStats.md)
 - [ClusterExecutionMetric](docs/ClusterExecutionMetric.md)
 - [ClusterExecutionMetrics](docs/ClusterExecutionMetrics.md)
 - [ClusterExecutionResult](docs/ClusterExecutionResult.md)
 - [ClusterListStats](docs/ClusterListStats.md)
 - [ClusterMetadata](docs/ClusterMetadata.md)
 - [ClusterModel](docs/ClusterModel.md)
 - [ClusterOptions](docs/ClusterOptions.md)
 - [ClusterStats](docs/ClusterStats.md)
 - [ClusterType](docs/ClusterType.md)
 - [ClusteringAlgorithm](docs/ClusteringAlgorithm.md)
 - [ClusteringEnrichmentResponse](docs/ClusteringEnrichmentResponse.md)
 - [CollectionDetail](docs/CollectionDetail.md)
 - [CollectionDiagnostic](docs/CollectionDiagnostic.md)
 - [CollectionExportRequest](docs/CollectionExportRequest.md)
 - [CollectionExportResponse](docs/CollectionExportResponse.md)
 - [CollectionFeatureDescriptor](docs/CollectionFeatureDescriptor.md)
 - [CollectionListStats](docs/CollectionListStats.md)
 - [CollectionModel](docs/CollectionModel.md)
 - [CollectionOverviewResponse](docs/CollectionOverviewResponse.md)
 - [CollectionResponse](docs/CollectionResponse.md)
 - [ColumnSource](docs/ColumnSource.md)
 - [ComponentsConfig](docs/ComponentsConfig.md)
 - [CompoundIndexPattern](docs/CompoundIndexPattern.md)
 - [CompoundIndexResponse](docs/CompoundIndexResponse.md)
 - [ComputeTier](docs/ComputeTier.md)
 - [ConfidenceDistribution](docs/ConfidenceDistribution.md)
 - [ConfidenceResponse](docs/ConfidenceResponse.md)
 - [Config](docs/Config.md)
 - [Config1](docs/Config1.md)
 - [Config2](docs/Config2.md)
 - [Configs](docs/Configs.md)
 - [ConfigureCORSRequest](docs/ConfigureCORSRequest.md)
 - [ConfirmModelUploadRequest](docs/ConfirmModelUploadRequest.md)
 - [ConfirmModelUploadResponse](docs/ConfirmModelUploadResponse.md)
 - [ConfirmPaymentMethodRequest](docs/ConfirmPaymentMethodRequest.md)
 - [ConfirmPaymentMethodResponse](docs/ConfirmPaymentMethodResponse.md)
 - [ConfirmPluginUploadRequest](docs/ConfirmPluginUploadRequest.md)
 - [ConfirmPluginUploadResponse](docs/ConfirmPluginUploadResponse.md)
 - [ConfirmUploadRequest](docs/ConfirmUploadRequest.md)
 - [ConfirmUploadResponse](docs/ConfirmUploadResponse.md)
 - [ConfirmationRequest](docs/ConfirmationRequest.md)
 - [ConstantSource](docs/ConstantSource.md)
 - [ContentInput](docs/ContentInput.md)
 - [ContentInput1](docs/ContentInput1.md)
 - [ContentQueryInput](docs/ContentQueryInput.md)
 - [ContentQueryInput1](docs/ContentQueryInput1.md)
 - [CostBreakdown](docs/CostBreakdown.md)
 - [CostRate](docs/CostRate.md)
 - [CostUnit](docs/CostUnit.md)
 - [CostsInfo](docs/CostsInfo.md)
 - [CourseContentExtractorParams](docs/CourseContentExtractorParams.md)
 - [CovariateConfig](docs/CovariateConfig.md)
 - [CovariateType](docs/CovariateType.md)
 - [CrawlMode](docs/CrawlMode.md)
 - [CreateAlertRequest](docs/CreateAlertRequest.md)
 - [CreateBatchRequest](docs/CreateBatchRequest.md)
 - [CreateBenchmarkRequest](docs/CreateBenchmarkRequest.md)
 - [CreateBlobRequest](docs/CreateBlobRequest.md)
 - [CreateClusterRequest](docs/CreateClusterRequest.md)
 - [CreateCollectionRequest](docs/CreateCollectionRequest.md)
 - [CreateDatasetRequest](docs/CreateDatasetRequest.md)
 - [CreateMigrationRequest](docs/CreateMigrationRequest.md)
 - [CreateMigrationResponse](docs/CreateMigrationResponse.md)
 - [CreateModelUploadRequest](docs/CreateModelUploadRequest.md)
 - [CreateNamespaceRequest](docs/CreateNamespaceRequest.md)
 - [CreateObjectRequest](docs/CreateObjectRequest.md)
 - [CreateObjectsBatchRequest](docs/CreateObjectsBatchRequest.md)
 - [CreateObjectsBatchResponse](docs/CreateObjectsBatchResponse.md)
 - [CreateOrganizationRequest](docs/CreateOrganizationRequest.md)
 - [CreateRetrieverRequest](docs/CreateRetrieverRequest.md)
 - [CreateRetrieverResponse](docs/CreateRetrieverResponse.md)
 - [CreateSecretRequest](docs/CreateSecretRequest.md)
 - [CreateSessionRequest](docs/CreateSessionRequest.md)
 - [CreateSessionResponse](docs/CreateSessionResponse.md)
 - [CreateTaxonomyRequest](docs/CreateTaxonomyRequest.md)
 - [CreateTemplateFromResourceRequest](docs/CreateTemplateFromResourceRequest.md)
 - [CreateTemplateFromResourceResponse](docs/CreateTemplateFromResourceResponse.md)
 - [CreateUploadRequest](docs/CreateUploadRequest.md)
 - [CreatorInfo](docs/CreatorInfo.md)
 - [Credentials](docs/Credentials.md)
 - [Credentials1](docs/Credentials1.md)
 - [Credentials2](docs/Credentials2.md)
 - [Credentials3](docs/Credentials3.md)
 - [CreditBalanceResponse](docs/CreditBalanceResponse.md)
 - [CurrentUsageResponse](docs/CurrentUsageResponse.md)
 - [CursorPaginationParams](docs/CursorPaginationParams.md)
 - [CustomCTA](docs/CustomCTA.md)
 - [CustomModelDocument](docs/CustomModelDocument.md)
 - [CustomPluginParams](docs/CustomPluginParams.md)
 - [DBSCANParams](docs/DBSCANParams.md)
 - [Data](docs/Data.md)
 - [DatasetListResponse](docs/DatasetListResponse.md)
 - [DatePartUnit](docs/DatePartUnit.md)
 - [DateTruncUnit](docs/DateTruncUnit.md)
 - [DatetimeIndexParams](docs/DatetimeIndexParams.md)
 - [DbscanParameters](docs/DbscanParameters.md)
 - [DependencyGraph](docs/DependencyGraph.md)
 - [DependencyNode](docs/DependencyNode.md)
 - [DescribeCollectionFeaturesResponse](docs/DescribeCollectionFeaturesResponse.md)
 - [DetectIntentRequest](docs/DetectIntentRequest.md)
 - [DiffItem](docs/DiffItem.md)
 - [DiffResult](docs/DiffResult.md)
 - [DisableOrgModelResponse](docs/DisableOrgModelResponse.md)
 - [DisableOrgPluginResponse](docs/DisableOrgPluginResponse.md)
 - [DisplayConfigInput](docs/DisplayConfigInput.md)
 - [DisplayConfigOutput](docs/DisplayConfigOutput.md)
 - [DiversityFeatureConfig](docs/DiversityFeatureConfig.md)
 - [DocumentAggregationRequest](docs/DocumentAggregationRequest.md)
 - [DocumentAggregationResponse](docs/DocumentAggregationResponse.md)
 - [DocumentCreateRequest](docs/DocumentCreateRequest.md)
 - [DocumentGraphExtractorParams](docs/DocumentGraphExtractorParams.md)
 - [DocumentGroup](docs/DocumentGroup.md)
 - [DocumentIdStrategy](docs/DocumentIdStrategy.md)
 - [DocumentListStats](docs/DocumentListStats.md)
 - [DocumentQueryInput](docs/DocumentQueryInput.md)
 - [DocumentQueryInput1](docs/DocumentQueryInput1.md)
 - [DocumentReference](docs/DocumentReference.md)
 - [DocumentReference1](docs/DocumentReference1.md)
 - [DocumentResponse](docs/DocumentResponse.md)
 - [DrivePropertySource](docs/DrivePropertySource.md)
 - [DurationStats](docs/DurationStats.md)
 - [DynamicValue](docs/DynamicValue.md)
 - [DynamicValue1](docs/DynamicValue1.md)
 - [DynamicValue2](docs/DynamicValue2.md)
 - [DynamicValue3](docs/DynamicValue3.md)
 - [DynamicValue4](docs/DynamicValue4.md)
 - [DynamicValue5](docs/DynamicValue5.md)
 - [DynamicValue6](docs/DynamicValue6.md)
 - [EmailConfig](docs/EmailConfig.md)
 - [EnableOrgModelRequest](docs/EnableOrgModelRequest.md)
 - [EnableOrgModelResponse](docs/EnableOrgModelResponse.md)
 - [EnableOrgPluginRequest](docs/EnableOrgPluginRequest.md)
 - [EnableOrgPluginResponse](docs/EnableOrgPluginResponse.md)
 - [EnginePerformanceResponse](docs/EnginePerformanceResponse.md)
 - [EngineStageBreakdownResponse](docs/EngineStageBreakdownResponse.md)
 - [EnrichmentField](docs/EnrichmentField.md)
 - [EnrichmentFieldMapping](docs/EnrichmentFieldMapping.md)
 - [EnrichmentHistoryResponse](docs/EnrichmentHistoryResponse.md)
 - [EnrichmentMergeMode](docs/EnrichmentMergeMode.md)
 - [EnrichmentMetric](docs/EnrichmentMetric.md)
 - [ErrorBreakdown](docs/ErrorBreakdown.md)
 - [ErrorCategory](docs/ErrorCategory.md)
 - [ErrorDetail](docs/ErrorDetail.md)
 - [ErrorHandling](docs/ErrorHandling.md)
 - [ErrorHandling1](docs/ErrorHandling1.md)
 - [ErrorHandling2](docs/ErrorHandling2.md)
 - [ErrorHandling3](docs/ErrorHandling3.md)
 - [ErrorMetrics](docs/ErrorMetrics.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [EvaluationConfig](docs/EvaluationConfig.md)
 - [EvaluationDataset](docs/EvaluationDataset.md)
 - [EvaluationListResponse](docs/EvaluationListResponse.md)
 - [EvaluationRecord](docs/EvaluationRecord.md)
 - [EvaluationStatus](docs/EvaluationStatus.md)
 - [ExecuteRetrieverRequest](docs/ExecuteRetrieverRequest.md)
 - [ExecuteTaxonomyRequest](docs/ExecuteTaxonomyRequest.md)
 - [ExecutionDetail](docs/ExecutionDetail.md)
 - [ExecutionHistoryResponse](docs/ExecutionHistoryResponse.md)
 - [ExplainRetrieverRequest](docs/ExplainRetrieverRequest.md)
 - [ExplainRetrieverResponse](docs/ExplainRetrieverResponse.md)
 - [ExplainStagePlan](docs/ExplainStagePlan.md)
 - [ExportFormat](docs/ExportFormat.md)
 - [ExternalLink](docs/ExternalLink.md)
 - [ExtractorBreakdownResponse](docs/ExtractorBreakdownResponse.md)
 - [ExtractorJobInfo](docs/ExtractorJobInfo.md)
 - [ExtractorMetrics](docs/ExtractorMetrics.md)
 - [ExtractorPerformance](docs/ExtractorPerformance.md)
 - [ExtractorPerformanceResponse](docs/ExtractorPerformanceResponse.md)
 - [ExtractorSource](docs/ExtractorSource.md)
 - [FaceIdentityExtractorParams](docs/FaceIdentityExtractorParams.md)
 - [FacetFieldConfig](docs/FacetFieldConfig.md)
 - [FailedObjectError](docs/FailedObjectError.md)
 - [FailureMetric](docs/FailureMetric.md)
 - [FeatureAddress](docs/FeatureAddress.md)
 - [FeatureExtractorResponseModel](docs/FeatureExtractorResponseModel.md)
 - [FeatureModel](docs/FeatureModel.md)
 - [FeatureSearchConfig](docs/FeatureSearchConfig.md)
 - [FeatureSearchGroupBy](docs/FeatureSearchGroupBy.md)
 - [FieldConfig](docs/FieldConfig.md)
 - [FieldFormatOptions](docs/FieldFormatOptions.md)
 - [FieldFormatType](docs/FieldFormatType.md)
 - [FieldMappingEntry](docs/FieldMappingEntry.md)
 - [FieldPassthrough](docs/FieldPassthrough.md)
 - [FieldPerformanceMetrics](docs/FieldPerformanceMetrics.md)
 - [FieldPerformanceResponse](docs/FieldPerformanceResponse.md)
 - [FieldQueryMetrics](docs/FieldQueryMetrics.md)
 - [FieldSchema](docs/FieldSchema.md)
 - [FieldUsageResponse](docs/FieldUsageResponse.md)
 - [FieldUsageStat](docs/FieldUsageStat.md)
 - [FileFilters](docs/FileFilters.md)
 - [FileSource](docs/FileSource.md)
 - [FilenameRegexSource](docs/FilenameRegexSource.md)
 - [FilterCondition](docs/FilterCondition.md)
 - [FilterCondition1](docs/FilterCondition1.md)
 - [FilterCondition2](docs/FilterCondition2.md)
 - [FilterCondition3](docs/FilterCondition3.md)
 - [FilterCondition4](docs/FilterCondition4.md)
 - [FilterCondition5](docs/FilterCondition5.md)
 - [FilterCondition6](docs/FilterCondition6.md)
 - [FilterOperator](docs/FilterOperator.md)
 - [FilterOperator1](docs/FilterOperator1.md)
 - [FilterOperator2](docs/FilterOperator2.md)
 - [FilterOperator3](docs/FilterOperator3.md)
 - [FilterOperator4](docs/FilterOperator4.md)
 - [FilterOperator5](docs/FilterOperator5.md)
 - [FilterOperator6](docs/FilterOperator6.md)
 - [FlatTaxonomyConfigInput](docs/FlatTaxonomyConfigInput.md)
 - [FlatTaxonomyConfigOutput](docs/FlatTaxonomyConfigOutput.md)
 - [FloatIndexParams](docs/FloatIndexParams.md)
 - [FolderItem](docs/FolderItem.md)
 - [FolderPathSource](docs/FolderPathSource.md)
 - [FusionStrategy](docs/FusionStrategy.md)
 - [GaussianMixtureParams](docs/GaussianMixtureParams.md)
 - [GenerationConfig](docs/GenerationConfig.md)
 - [GenericDeleteResponse](docs/GenericDeleteResponse.md)
 - [GenericSuccessResponse](docs/GenericSuccessResponse.md)
 - [GeoIndexParams](docs/GeoIndexParams.md)
 - [GetHistoryResponse](docs/GetHistoryResponse.md)
 - [GetMigrationResponse](docs/GetMigrationResponse.md)
 - [GetPaymentMethodResponse](docs/GetPaymentMethodResponse.md)
 - [GetSessionResponse](docs/GetSessionResponse.md)
 - [GoogleDriveConfig](docs/GoogleDriveConfig.md)
 - [GoogleDriveOAuthCredentials](docs/GoogleDriveOAuthCredentials.md)
 - [GoogleDriveServiceAccountCredentials](docs/GoogleDriveServiceAccountCredentials.md)
 - [GoogleModel](docs/GoogleModel.md)
 - [GroundTruthQuery](docs/GroundTruthQuery.md)
 - [GroupByField](docs/GroupByField.md)
 - [GroupByFieldConfig](docs/GroupByFieldConfig.md)
 - [GrowthMetric](docs/GrowthMetric.md)
 - [GrowthMetricsResponse](docs/GrowthMetricsResponse.md)
 - [HDBSCANParams](docs/HDBSCANParams.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [HavingCondition](docs/HavingCondition.md)
 - [HdbscanParameters](docs/HdbscanParameters.md)
 - [HealthCheck](docs/HealthCheck.md)
 - [HealthCheckResponse](docs/HealthCheckResponse.md)
 - [HealthServiceErrors](docs/HealthServiceErrors.md)
 - [HealthServiceStatus](docs/HealthServiceStatus.md)
 - [HealthStatusInput](docs/HealthStatusInput.md)
 - [HealthStatusOutput](docs/HealthStatusOutput.md)
 - [HierarchicalEnrichmentStyle](docs/HierarchicalEnrichmentStyle.md)
 - [HierarchicalNodeInput](docs/HierarchicalNodeInput.md)
 - [HierarchicalNodeOutput](docs/HierarchicalNodeOutput.md)
 - [HierarchicalTaxonomyConfigInput](docs/HierarchicalTaxonomyConfigInput.md)
 - [HierarchicalTaxonomyConfigOutput](docs/HierarchicalTaxonomyConfigOutput.md)
 - [HierarchyInferenceStrategy](docs/HierarchyInferenceStrategy.md)
 - [ImageExtractorParams](docs/ImageExtractorParams.md)
 - [Index](docs/Index.md)
 - [IndexRecommendation](docs/IndexRecommendation.md)
 - [IndexRecommendationsResponse](docs/IndexRecommendationsResponse.md)
 - [IndexSuggestion](docs/IndexSuggestion.md)
 - [IndexSuggestionsResponse](docs/IndexSuggestionsResponse.md)
 - [InputMapping](docs/InputMapping.md)
 - [InputMappingSource](docs/InputMappingSource.md)
 - [InputMappings](docs/InputMappings.md)
 - [InputRenderingConfigInput](docs/InputRenderingConfigInput.md)
 - [InputRenderingConfigOutput](docs/InputRenderingConfigOutput.md)
 - [InputSourceType](docs/InputSourceType.md)
 - [InstantiateBucketTemplateRequest](docs/InstantiateBucketTemplateRequest.md)
 - [InstantiateClusterTemplateRequest](docs/InstantiateClusterTemplateRequest.md)
 - [InstantiateCollectionTemplateRequest](docs/InstantiateCollectionTemplateRequest.md)
 - [InstantiateRetrieverTemplateRequest](docs/InstantiateRetrieverTemplateRequest.md)
 - [InstantiateScaffoldRequest](docs/InstantiateScaffoldRequest.md)
 - [InstantiateTaxonomyTemplateRequest](docs/InstantiateTaxonomyTemplateRequest.md)
 - [InstantiateTemplateRequest](docs/InstantiateTemplateRequest.md)
 - [InstantiatedBucketTemplateResponse](docs/InstantiatedBucketTemplateResponse.md)
 - [InstantiatedClusterTemplateResponse](docs/InstantiatedClusterTemplateResponse.md)
 - [InstantiatedCollectionTemplateResponse](docs/InstantiatedCollectionTemplateResponse.md)
 - [InstantiatedRetrieverTemplateResponse](docs/InstantiatedRetrieverTemplateResponse.md)
 - [InstantiatedScaffoldResponse](docs/InstantiatedScaffoldResponse.md)
 - [InstantiatedTaxonomyTemplateResponse](docs/InstantiatedTaxonomyTemplateResponse.md)
 - [InstantiatedTemplateResponse](docs/InstantiatedTemplateResponse.md)
 - [IntegerIndexParams](docs/IntegerIndexParams.md)
 - [IntentClassification](docs/IntentClassification.md)
 - [InteractionResponse](docs/InteractionResponse.md)
 - [InteractionTuningRecommendation](docs/InteractionTuningRecommendation.md)
 - [InteractionTuningResponse](docs/InteractionTuningResponse.md)
 - [InteractionType](docs/InteractionType.md)
 - [InteractionWeights](docs/InteractionWeights.md)
 - [InternalLineageModel](docs/InternalLineageModel.md)
 - [InternalPayloadModel](docs/InternalPayloadModel.md)
 - [InternalProcessingModel](docs/InternalProcessingModel.md)
 - [InvoiceInfo](docs/InvoiceInfo.md)
 - [InvoiceListResponse](docs/InvoiceListResponse.md)
 - [JoinMode](docs/JoinMode.md)
 - [JoinResponse](docs/JoinResponse.md)
 - [JoinStats](docs/JoinStats.md)
 - [KMeansParams](docs/KMeansParams.md)
 - [KeyStatus](docs/KeyStatus.md)
 - [KeysetPaginationParams](docs/KeysetPaginationParams.md)
 - [KeywordIndexParams](docs/KeywordIndexParams.md)
 - [KmeansParameters](docs/KmeansParameters.md)
 - [LLMLabelingInput](docs/LLMLabelingInput.md)
 - [LLMLabelingInputInput](docs/LLMLabelingInputInput.md)
 - [LLMLabelingInputOutput](docs/LLMLabelingInputOutput.md)
 - [LLMLabelingOutput](docs/LLMLabelingOutput.md)
 - [LLMProvider](docs/LLMProvider.md)
 - [LLMProvider1](docs/LLMProvider1.md)
 - [LLMProvider2](docs/LLMProvider2.md)
 - [LabelDistributionResponse](docs/LabelDistributionResponse.md)
 - [LabelMetric](docs/LabelMetric.md)
 - [LatencyMetric](docs/LatencyMetric.md)
 - [LatencyMetrics](docs/LatencyMetrics.md)
 - [LatencyResponse](docs/LatencyResponse.md)
 - [LayoutConfig](docs/LayoutConfig.md)
 - [LearnedFusionConfig](docs/LearnedFusionConfig.md)
 - [LearningAlgorithm](docs/LearningAlgorithm.md)
 - [LineageStep](docs/LineageStep.md)
 - [ListAdhocExecutionsRequest](docs/ListAdhocExecutionsRequest.md)
 - [ListAdhocExecutionsResponse](docs/ListAdhocExecutionsResponse.md)
 - [ListAlertsRequest](docs/ListAlertsRequest.md)
 - [ListAlertsResponse](docs/ListAlertsResponse.md)
 - [ListBatchesRequest](docs/ListBatchesRequest.md)
 - [ListBatchesResponse](docs/ListBatchesResponse.md)
 - [ListBucketsRequest](docs/ListBucketsRequest.md)
 - [ListBucketsResponse](docs/ListBucketsResponse.md)
 - [ListClusterExecutionsRequest](docs/ListClusterExecutionsRequest.md)
 - [ListClusterExecutionsResponse](docs/ListClusterExecutionsResponse.md)
 - [ListClustersRequest](docs/ListClustersRequest.md)
 - [ListClustersResponse](docs/ListClustersResponse.md)
 - [ListCollectionsRequest](docs/ListCollectionsRequest.md)
 - [ListCollectionsResponse](docs/ListCollectionsResponse.md)
 - [ListDocumentsRequest](docs/ListDocumentsRequest.md)
 - [ListDocumentsResponse](docs/ListDocumentsResponse.md)
 - [ListExecutionsRequest](docs/ListExecutionsRequest.md)
 - [ListExecutionsResponse](docs/ListExecutionsResponse.md)
 - [ListFoldersResponse](docs/ListFoldersResponse.md)
 - [ListInteractionsRequest](docs/ListInteractionsRequest.md)
 - [ListInteractionsResponse](docs/ListInteractionsResponse.md)
 - [ListMigrationsRequest](docs/ListMigrationsRequest.md)
 - [ListMigrationsResponse](docs/ListMigrationsResponse.md)
 - [ListNamespacesRequest](docs/ListNamespacesRequest.md)
 - [ListNamespacesResponse](docs/ListNamespacesResponse.md)
 - [ListNotificationsRequest](docs/ListNotificationsRequest.md)
 - [ListNotificationsResponse](docs/ListNotificationsResponse.md)
 - [ListObjectsRequest](docs/ListObjectsRequest.md)
 - [ListObjectsResponse](docs/ListObjectsResponse.md)
 - [ListPublicRetrieversResponse](docs/ListPublicRetrieversResponse.md)
 - [ListRetrieversRequest](docs/ListRetrieversRequest.md)
 - [ListRetrieversResponse](docs/ListRetrieversResponse.md)
 - [ListSessionsRequest](docs/ListSessionsRequest.md)
 - [ListSessionsResponse](docs/ListSessionsResponse.md)
 - [ListStorageConnectionsRequest](docs/ListStorageConnectionsRequest.md)
 - [ListSyncConfigurationsRequest](docs/ListSyncConfigurationsRequest.md)
 - [ListTasksRequest](docs/ListTasksRequest.md)
 - [ListTasksResponse](docs/ListTasksResponse.md)
 - [ListTaxonomiesRequest](docs/ListTaxonomiesRequest.md)
 - [ListTaxonomiesResponse](docs/ListTaxonomiesResponse.md)
 - [ListTemplatesRequest](docs/ListTemplatesRequest.md)
 - [ListTemplatesResponse](docs/ListTemplatesResponse.md)
 - [ListToolsResponse](docs/ListToolsResponse.md)
 - [ListUploadsRequest](docs/ListUploadsRequest.md)
 - [ListUploadsResponse](docs/ListUploadsResponse.md)
 - [ListWebhooksRequest](docs/ListWebhooksRequest.md)
 - [ListWebhooksResponse](docs/ListWebhooksResponse.md)
 - [LogicalOperator](docs/LogicalOperator.md)
 - [LogicalOperator1](docs/LogicalOperator1.md)
 - [LogicalOperator2](docs/LogicalOperator2.md)
 - [LogicalOperator3](docs/LogicalOperator3.md)
 - [LogicalOperator4](docs/LogicalOperator4.md)
 - [LogicalOperator5](docs/LogicalOperator5.md)
 - [LogicalOperator6](docs/LogicalOperator6.md)
 - [LogicalOperatorInput](docs/LogicalOperatorInput.md)
 - [LogicalOperatorOutput](docs/LogicalOperatorOutput.md)
 - [MappingsValue](docs/MappingsValue.md)
 - [MarkAsReadRequest](docs/MarkAsReadRequest.md)
 - [MarkdownContent](docs/MarkdownContent.md)
 - [MeanShiftParams](docs/MeanShiftParams.md)
 - [MessageHistoryItem](docs/MessageHistoryItem.md)
 - [MigrationConfig](docs/MigrationConfig.md)
 - [MigrationProgress](docs/MigrationProgress.md)
 - [MigrationStage](docs/MigrationStage.md)
 - [MigrationStatus](docs/MigrationStatus.md)
 - [MigrationType](docs/MigrationType.md)
 - [ModelDeleteResponse](docs/ModelDeleteResponse.md)
 - [ModelDeployResponse](docs/ModelDeployResponse.md)
 - [ModelDeploymentInfo](docs/ModelDeploymentInfo.md)
 - [ModelDetailResponse](docs/ModelDetailResponse.md)
 - [ModelListItem](docs/ModelListItem.md)
 - [ModelListResponse](docs/ModelListResponse.md)
 - [ModelName](docs/ModelName.md)
 - [ModelPresignedURLResponse](docs/ModelPresignedURLResponse.md)
 - [ModelResourceRequirements](docs/ModelResourceRequirements.md)
 - [ModelUploadResponse](docs/ModelUploadResponse.md)
 - [MostQueriedFieldsResponse](docs/MostQueriedFieldsResponse.md)
 - [MultiVectorIndex](docs/MultiVectorIndex.md)
 - [MultimodalExtractorParams](docs/MultimodalExtractorParams.md)
 - [NamespaceInfrastructure](docs/NamespaceInfrastructure.md)
 - [NamespaceListStats](docs/NamespaceListStats.md)
 - [NamespaceModel](docs/NamespaceModel.md)
 - [NamespaceOperation](docs/NamespaceOperation.md)
 - [NamespaceSummaryResponse](docs/NamespaceSummaryResponse.md)
 - [Notification](docs/Notification.md)
 - [NotificationChannel](docs/NotificationChannel.md)
 - [NotificationChannelConfig](docs/NotificationChannelConfig.md)
 - [NotificationContentType](docs/NotificationContentType.md)
 - [NotificationPriority](docs/NotificationPriority.md)
 - [NotificationType](docs/NotificationType.md)
 - [OPTICSParams](docs/OPTICSParams.md)
 - [ObjectAggregationRequest](docs/ObjectAggregationRequest.md)
 - [ObjectAggregationResponse](docs/ObjectAggregationResponse.md)
 - [ObjectListStats](docs/ObjectListStats.md)
 - [ObjectResponse](docs/ObjectResponse.md)
 - [OffsetPaginationParams](docs/OffsetPaginationParams.md)
 - [OnEmptyBehavior](docs/OnEmptyBehavior.md)
 - [OnEmptyBehavior1](docs/OnEmptyBehavior1.md)
 - [OnNoResults](docs/OnNoResults.md)
 - [OpenAIModel](docs/OpenAIModel.md)
 - [OrgModelDeleteResponse](docs/OrgModelDeleteResponse.md)
 - [OrgModelDeploymentInfo](docs/OrgModelDeploymentInfo.md)
 - [OrgModelDetailResponse](docs/OrgModelDetailResponse.md)
 - [OrgModelDocument](docs/OrgModelDocument.md)
 - [OrgModelListItem](docs/OrgModelListItem.md)
 - [OrgModelListResponse](docs/OrgModelListResponse.md)
 - [OrganizationAdminUpdateRequest](docs/OrganizationAdminUpdateRequest.md)
 - [OrganizationInfrastructure](docs/OrganizationInfrastructure.md)
 - [OrganizationModel](docs/OrganizationModel.md)
 - [OrganizationModelResponse](docs/OrganizationModelResponse.md)
 - [OrganizationPublishStatsResponse](docs/OrganizationPublishStatsResponse.md)
 - [OrganizationUpdateRequest](docs/OrganizationUpdateRequest.md)
 - [Pagination](docs/Pagination.md)
 - [PaginationMetadata](docs/PaginationMetadata.md)
 - [PaginationMethod](docs/PaginationMethod.md)
 - [PaginationResponse](docs/PaginationResponse.md)
 - [Parameters](docs/Parameters.md)
 - [PatchAlertRequest](docs/PatchAlertRequest.md)
 - [PatchBatchRequest](docs/PatchBatchRequest.md)
 - [PatchClusterRequest](docs/PatchClusterRequest.md)
 - [PatchNamespaceRequest](docs/PatchNamespaceRequest.md)
 - [PatchObjectRequest](docs/PatchObjectRequest.md)
 - [PatchRetrieverRequest](docs/PatchRetrieverRequest.md)
 - [PatchRetrieverResponse](docs/PatchRetrieverResponse.md)
 - [PatchSessionRequest](docs/PatchSessionRequest.md)
 - [PatchSessionResponse](docs/PatchSessionResponse.md)
 - [PatchTaxonomyRequest](docs/PatchTaxonomyRequest.md)
 - [PathAnalysisRequest](docs/PathAnalysisRequest.md)
 - [PathAnalysisResponse](docs/PathAnalysisResponse.md)
 - [Payload](docs/Payload.md)
 - [PayloadIndexConfigInput](docs/PayloadIndexConfigInput.md)
 - [PayloadIndexConfigOutput](docs/PayloadIndexConfigOutput.md)
 - [PayloadSchemaType](docs/PayloadSchemaType.md)
 - [PaymentMethodInfo](docs/PaymentMethodInfo.md)
 - [PerformanceInsight](docs/PerformanceInsight.md)
 - [PerformanceMetric](docs/PerformanceMetric.md)
 - [PerformanceSummary](docs/PerformanceSummary.md)
 - [Permission](docs/Permission.md)
 - [PipelineComparison](docs/PipelineComparison.md)
 - [PluginDeploymentInfo](docs/PluginDeploymentInfo.md)
 - [PluginListItem](docs/PluginListItem.md)
 - [PluginStatusResponse](docs/PluginStatusResponse.md)
 - [PluginUploadResponse](docs/PluginUploadResponse.md)
 - [PostProcessingPhase](docs/PostProcessingPhase.md)
 - [PostgreSQLConfig](docs/PostgreSQLConfig.md)
 - [PostgreSQLCredentials](docs/PostgreSQLCredentials.md)
 - [PredictorLift](docs/PredictorLift.md)
 - [ProviderConfig](docs/ProviderConfig.md)
 - [PublicInteractionBatchRequest](docs/PublicInteractionBatchRequest.md)
 - [PublicInteractionRequest](docs/PublicInteractionRequest.md)
 - [PublicNameAvailabilityResponse](docs/PublicNameAvailabilityResponse.md)
 - [PublicRetrieverConfigResponse](docs/PublicRetrieverConfigResponse.md)
 - [PublicRetrieverListItem](docs/PublicRetrieverListItem.md)
 - [PublicRetrieverListStats](docs/PublicRetrieverListStats.md)
 - [PublicRetrieverTemplateResponse](docs/PublicRetrieverTemplateResponse.md)
 - [PublishRetrieverRequest](docs/PublishRetrieverRequest.md)
 - [PublishRetrieverResponse](docs/PublishRetrieverResponse.md)
 - [PublishedRetrieverResponse](docs/PublishedRetrieverResponse.md)
 - [Query](docs/Query.md)
 - [RangeBucket](docs/RangeBucket.md)
 - [RangeBucketBoundariesInner](docs/RangeBucketBoundariesInner.md)
 - [RateLimitConfig](docs/RateLimitConfig.md)
 - [RateLimitTier](docs/RateLimitTier.md)
 - [RawInferenceRequest](docs/RawInferenceRequest.md)
 - [RawInferenceResponse](docs/RawInferenceResponse.md)
 - [ReminderPreferences](docs/ReminderPreferences.md)
 - [ReminderPreferencesResponse](docs/ReminderPreferencesResponse.md)
 - [RenderStrategy](docs/RenderStrategy.md)
 - [ResourceFilter](docs/ResourceFilter.md)
 - [ResourceProgress](docs/ResourceProgress.md)
 - [ResourceResult](docs/ResourceResult.md)
 - [ResourceResultStatus](docs/ResourceResultStatus.md)
 - [ResourceScopeInput](docs/ResourceScopeInput.md)
 - [ResourceScopeOutput](docs/ResourceScopeOutput.md)
 - [ResourceTypeInput](docs/ResourceTypeInput.md)
 - [ResponseShape](docs/ResponseShape.md)
 - [ResponseShape1](docs/ResponseShape1.md)
 - [ResponseShape2](docs/ResponseShape2.md)
 - [ResponseShape3](docs/ResponseShape3.md)
 - [ResponseSyncCollectionSchemaV1CollectionsCollectionIdSyncSchemaPost](docs/ResponseSyncCollectionSchemaV1CollectionsCollectionIdSyncSchemaPost.md)
 - [ResultCardProperties](docs/ResultCardProperties.md)
 - [ResultHandling](docs/ResultHandling.md)
 - [RetrieverConfig](docs/RetrieverConfig.md)
 - [RetrieverExecutionRequest](docs/RetrieverExecutionRequest.md)
 - [RetrieverExecutionStatistics](docs/RetrieverExecutionStatistics.md)
 - [RetrieverExecutionSummary](docs/RetrieverExecutionSummary.md)
 - [RetrieverInputSchemaFieldInput](docs/RetrieverInputSchemaFieldInput.md)
 - [RetrieverInputSchemaFieldOutput](docs/RetrieverInputSchemaFieldOutput.md)
 - [RetrieverInputSchemaFieldType](docs/RetrieverInputSchemaFieldType.md)
 - [RetrieverMetadata](docs/RetrieverMetadata.md)
 - [RetrieverModelInput](docs/RetrieverModelInput.md)
 - [RetrieverModelOutput](docs/RetrieverModelOutput.md)
 - [RetrieverOptions](docs/RetrieverOptions.md)
 - [RetrieverPerformanceResponse](docs/RetrieverPerformanceResponse.md)
 - [RetrieverSchema](docs/RetrieverSchema.md)
 - [RetrieverSignal](docs/RetrieverSignal.md)
 - [RetrieverStageDefinition](docs/RetrieverStageDefinition.md)
 - [RetrieverStatus](docs/RetrieverStatus.md)
 - [RetryBatchRequest](docs/RetryBatchRequest.md)
 - [RevisionHistoryEntry](docs/RevisionHistoryEntry.md)
 - [S3AccessKeyCredentials](docs/S3AccessKeyCredentials.md)
 - [S3Config](docs/S3Config.md)
 - [S3MetadataSource](docs/S3MetadataSource.md)
 - [S3RoleCredentials](docs/S3RoleCredentials.md)
 - [S3TagSource](docs/S3TagSource.md)
 - [SEOConfig](docs/SEOConfig.md)
 - [SchemaMappingInput](docs/SchemaMappingInput.md)
 - [SchemaMappingOutput](docs/SchemaMappingOutput.md)
 - [SchemaSyncRequest](docs/SchemaSyncRequest.md)
 - [SchemaSyncResponse](docs/SchemaSyncResponse.md)
 - [SchemaSyncSkippedResponse](docs/SchemaSyncSkippedResponse.md)
 - [ScrollPaginationParams](docs/ScrollPaginationParams.md)
 - [SearchInteraction](docs/SearchInteraction.md)
 - [SearchRequest](docs/SearchRequest.md)
 - [SearchResponse](docs/SearchResponse.md)
 - [SearchResultItem](docs/SearchResultItem.md)
 - [SecretResponse](docs/SecretResponse.md)
 - [SecretsListResponse](docs/SecretsListResponse.md)
 - [SendMessageRequest](docs/SendMessageRequest.md)
 - [SentimentClassifierParams](docs/SentimentClassifierParams.md)
 - [SessionFilterInput](docs/SessionFilterInput.md)
 - [SessionFilterOutput](docs/SessionFilterOutput.md)
 - [SessionQuotas](docs/SessionQuotas.md)
 - [SessionStats](docs/SessionStats.md)
 - [SessionStatus](docs/SessionStatus.md)
 - [SetupPaymentMethodResponse](docs/SetupPaymentMethodResponse.md)
 - [SharePointClientCredentials](docs/SharePointClientCredentials.md)
 - [SharePointConfig](docs/SharePointConfig.md)
 - [SharePointDelegatedCredentials](docs/SharePointDelegatedCredentials.md)
 - [SharedClustersTriggersModelsCreateTriggerRequest](docs/SharedClustersTriggersModelsCreateTriggerRequest.md)
 - [SharedClustersTriggersModelsListTriggersRequest](docs/SharedClustersTriggersModelsListTriggersRequest.md)
 - [SharedClustersTriggersModelsListTriggersResponse](docs/SharedClustersTriggersModelsListTriggersResponse.md)
 - [SharedClustersTriggersModelsTriggerHistoryResponse](docs/SharedClustersTriggersModelsTriggerHistoryResponse.md)
 - [SharedClustersTriggersModelsTriggerModel](docs/SharedClustersTriggersModelsTriggerModel.md)
 - [SharedClustersTriggersModelsTriggerStatus](docs/SharedClustersTriggersModelsTriggerStatus.md)
 - [SharedClustersTriggersModelsTriggerType](docs/SharedClustersTriggersModelsTriggerType.md)
 - [SharedClustersTriggersModelsUpdateTriggerRequest](docs/SharedClustersTriggersModelsUpdateTriggerRequest.md)
 - [SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigInput](docs/SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigInput.md)
 - [SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput](docs/SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput.md)
 - [SharedNamespacesMigrationsModelsFeatureExtractorConfig](docs/SharedNamespacesMigrationsModelsFeatureExtractorConfig.md)
 - [SharedNamespacesMigrationsModelsResourceType](docs/SharedNamespacesMigrationsModelsResourceType.md)
 - [SharedOrganizationsEnumsResourceType](docs/SharedOrganizationsEnumsResourceType.md)
 - [SharedRetrieversBenchmarksModelsTimeRange](docs/SharedRetrieversBenchmarksModelsTimeRange.md)
 - [SharedTriggersModelsCreateTriggerRequest](docs/SharedTriggersModelsCreateTriggerRequest.md)
 - [SharedTriggersModelsListTriggersRequest](docs/SharedTriggersModelsListTriggersRequest.md)
 - [SharedTriggersModelsListTriggersResponse](docs/SharedTriggersModelsListTriggersResponse.md)
 - [SharedTriggersModelsTriggerHistoryResponse](docs/SharedTriggersModelsTriggerHistoryResponse.md)
 - [SharedTriggersModelsTriggerModel](docs/SharedTriggersModelsTriggerModel.md)
 - [SharedTriggersModelsTriggerStatus](docs/SharedTriggersModelsTriggerStatus.md)
 - [SharedTriggersModelsTriggerType](docs/SharedTriggersModelsTriggerType.md)
 - [SharedTriggersModelsUpdateTriggerRequest](docs/SharedTriggersModelsUpdateTriggerRequest.md)
 - [SingleLineageEntry](docs/SingleLineageEntry.md)
 - [SlackConfig](docs/SlackConfig.md)
 - [SlowOperation](docs/SlowOperation.md)
 - [SlowOperationsResponse](docs/SlowOperationsResponse.md)
 - [SlowQueriesResponse](docs/SlowQueriesResponse.md)
 - [SlowQueryDetails](docs/SlowQueryDetails.md)
 - [SnowflakeConfig](docs/SnowflakeConfig.md)
 - [SnowflakeKeyPairCredentials](docs/SnowflakeKeyPairCredentials.md)
 - [SnowflakeUsernamePasswordCredentials](docs/SnowflakeUsernamePasswordCredentials.md)
 - [SortDirection](docs/SortDirection.md)
 - [SortDirection1](docs/SortDirection1.md)
 - [SortOption](docs/SortOption.md)
 - [Source](docs/Source.md)
 - [Source1](docs/Source1.md)
 - [SourceCollectionInput](docs/SourceCollectionInput.md)
 - [SourceCollectionOutput](docs/SourceCollectionOutput.md)
 - [SourceConfigInput](docs/SourceConfigInput.md)
 - [SourceConfigOutput](docs/SourceConfigOutput.md)
 - [SourceDetails](docs/SourceDetails.md)
 - [SourceEnrichmentConfig](docs/SourceEnrichmentConfig.md)
 - [SourceFiltersInput](docs/SourceFiltersInput.md)
 - [SourceFiltersOutput](docs/SourceFiltersOutput.md)
 - [SourceType](docs/SourceType.md)
 - [SparseVector](docs/SparseVector.md)
 - [SpectralParams](docs/SpectralParams.md)
 - [SpendingCapsResponse](docs/SpendingCapsResponse.md)
 - [SplitMethod](docs/SplitMethod.md)
 - [StageBreakdownResponse](docs/StageBreakdownResponse.md)
 - [StageCacheBehavior](docs/StageCacheBehavior.md)
 - [StageCacheBehavior1](docs/StageCacheBehavior1.md)
 - [StageCategory](docs/StageCategory.md)
 - [StageConfig](docs/StageConfig.md)
 - [StageInstanceConfig](docs/StageInstanceConfig.md)
 - [StageParamsAggregate](docs/StageParamsAggregate.md)
 - [StageParamsApiCall](docs/StageParamsApiCall.md)
 - [StageParamsAttributeFilter](docs/StageParamsAttributeFilter.md)
 - [StageParamsCluster](docs/StageParamsCluster.md)
 - [StageParamsCodeExecution](docs/StageParamsCodeExecution.md)
 - [StageParamsDocumentEnrich](docs/StageParamsDocumentEnrich.md)
 - [StageParamsExternalWebSearch](docs/StageParamsExternalWebSearch.md)
 - [StageParamsFeatureSearch](docs/StageParamsFeatureSearch.md)
 - [StageParamsGroupBy](docs/StageParamsGroupBy.md)
 - [StageParamsJsonTransform](docs/StageParamsJsonTransform.md)
 - [StageParamsLlmEnrich](docs/StageParamsLlmEnrich.md)
 - [StageParamsLlmFilter](docs/StageParamsLlmFilter.md)
 - [StageParamsMmr](docs/StageParamsMmr.md)
 - [StageParamsQueryExpand](docs/StageParamsQueryExpand.md)
 - [StageParamsRagPrepare](docs/StageParamsRagPrepare.md)
 - [StageParamsRerank](docs/StageParamsRerank.md)
 - [StageParamsSample](docs/StageParamsSample.md)
 - [StageParamsSortAttribute](docs/StageParamsSortAttribute.md)
 - [StageParamsSortRelevance](docs/StageParamsSortRelevance.md)
 - [StageParamsSqlLookup](docs/StageParamsSqlLookup.md)
 - [StageParamsSummarize](docs/StageParamsSummarize.md)
 - [StageParamsTaxonomyEnrich](docs/StageParamsTaxonomyEnrich.md)
 - [StageParamsWebScrape](docs/StageParamsWebScrape.md)
 - [StagePerformanceInput](docs/StagePerformanceInput.md)
 - [StagePerformanceMetrics](docs/StagePerformanceMetrics.md)
 - [StagePerformanceOutput](docs/StagePerformanceOutput.md)
 - [StageProgress](docs/StageProgress.md)
 - [StageStatistics](docs/StageStatistics.md)
 - [StageType](docs/StageType.md)
 - [StageTypesContentInput](docs/StageTypesContentInput.md)
 - [StageTypesDocumentReference](docs/StageTypesDocumentReference.md)
 - [StageTypesFeatureSearchConfig](docs/StageTypesFeatureSearchConfig.md)
 - [StageTypesFusionStrategy](docs/StageTypesFusionStrategy.md)
 - [StageTypesOnEmptyBehavior](docs/StageTypesOnEmptyBehavior.md)
 - [StartEvaluationRequest](docs/StartEvaluationRequest.md)
 - [StartEvaluationResponse](docs/StartEvaluationResponse.md)
 - [StartMigrationRequest](docs/StartMigrationRequest.md)
 - [StartMigrationResponse](docs/StartMigrationResponse.md)
 - [StepAnalyticsConfigInput](docs/StepAnalyticsConfigInput.md)
 - [StepAnalyticsConfigOutput](docs/StepAnalyticsConfigOutput.md)
 - [StepInfo](docs/StepInfo.md)
 - [StepKeySource](docs/StepKeySource.md)
 - [StepTransitionRequest](docs/StepTransitionRequest.md)
 - [StepTransitionResponse](docs/StepTransitionResponse.md)
 - [StorageConnectionCreateRequest](docs/StorageConnectionCreateRequest.md)
 - [StorageConnectionListResponse](docs/StorageConnectionListResponse.md)
 - [StorageConnectionModel](docs/StorageConnectionModel.md)
 - [StorageConnectionTestResponse](docs/StorageConnectionTestResponse.md)
 - [StorageConnectionUpdateRequest](docs/StorageConnectionUpdateRequest.md)
 - [StorageMetric](docs/StorageMetric.md)
 - [StorageProvider](docs/StorageProvider.md)
 - [StorageStatistics](docs/StorageStatistics.md)
 - [StructuredDataConfig](docs/StructuredDataConfig.md)
 - [SubmitBatchRequest](docs/SubmitBatchRequest.md)
 - [SubmitFeedbackRequest](docs/SubmitFeedbackRequest.md)
 - [SubmitFeedbackResponse](docs/SubmitFeedbackResponse.md)
 - [SuitableCollection](docs/SuitableCollection.md)
 - [SyncComparisonResponse](docs/SyncComparisonResponse.md)
 - [SyncConfigMetric](docs/SyncConfigMetric.md)
 - [SyncConfigurationModel](docs/SyncConfigurationModel.md)
 - [SyncCreateRequest](docs/SyncCreateRequest.md)
 - [SyncHealthMetric](docs/SyncHealthMetric.md)
 - [SyncListResponse](docs/SyncListResponse.md)
 - [SyncMode](docs/SyncMode.md)
 - [SyncPerformanceResponse](docs/SyncPerformanceResponse.md)
 - [SyncRunMetric](docs/SyncRunMetric.md)
 - [SyncUpdateRequest](docs/SyncUpdateRequest.md)
 - [TaskProgress](docs/TaskProgress.md)
 - [TaskResponse](docs/TaskResponse.md)
 - [TaskResponseInputsInner](docs/TaskResponseInputsInner.md)
 - [TaskStatusEnum](docs/TaskStatusEnum.md)
 - [TaskStatusUpdateRequest](docs/TaskStatusUpdateRequest.md)
 - [TaskType](docs/TaskType.md)
 - [TaxonomyApplicationConfigInput](docs/TaxonomyApplicationConfigInput.md)
 - [TaxonomyApplicationConfigOutput](docs/TaxonomyApplicationConfigOutput.md)
 - [TaxonomyExecutionMode](docs/TaxonomyExecutionMode.md)
 - [TaxonomyListStats](docs/TaxonomyListStats.md)
 - [TaxonomyModelInput](docs/TaxonomyModelInput.md)
 - [TaxonomyModelOutput](docs/TaxonomyModelOutput.md)
 - [TaxonomyOptions](docs/TaxonomyOptions.md)
 - [TaxonomyResponse](docs/TaxonomyResponse.md)
 - [TemplateMode](docs/TemplateMode.md)
 - [TemplateScope](docs/TemplateScope.md)
 - [TemplateType](docs/TemplateType.md)
 - [TerminateSessionResponse](docs/TerminateSessionResponse.md)
 - [TextExtractorParams](docs/TextExtractorParams.md)
 - [TextIndexParams](docs/TextIndexParams.md)
 - [TextQueryInput](docs/TextQueryInput.md)
 - [TextQueryInput1](docs/TextQueryInput1.md)
 - [TextSplitStrategy](docs/TextSplitStrategy.md)
 - [ThemeConfig](docs/ThemeConfig.md)
 - [TierDiagnostic](docs/TierDiagnostic.md)
 - [TierTaskInfo](docs/TierTaskInfo.md)
 - [TigrisAccessKeyCredentials](docs/TigrisAccessKeyCredentials.md)
 - [TigrisConfig](docs/TigrisConfig.md)
 - [TimeRangeInput](docs/TimeRangeInput.md)
 - [TokenizerType](docs/TokenizerType.md)
 - [ToolInfo](docs/ToolInfo.md)
 - [TransitionPath](docs/TransitionPath.md)
 - [TriggerActionType](docs/TriggerActionType.md)
 - [TriggerCollectionRequest](docs/TriggerCollectionRequest.md)
 - [TriggerCollectionResponse](docs/TriggerCollectionResponse.md)
 - [TriggerExecutionConfig](docs/TriggerExecutionConfig.md)
 - [TriggerExecutionHistory](docs/TriggerExecutionHistory.md)
 - [TriggerExecutionHistoryItem](docs/TriggerExecutionHistoryItem.md)
 - [TriggerHistoryRequest](docs/TriggerHistoryRequest.md)
 - [TriggerTierRequest](docs/TriggerTierRequest.md)
 - [URLPatterns](docs/URLPatterns.md)
 - [UnifiedExtractorListResponse](docs/UnifiedExtractorListResponse.md)
 - [UnifiedExtractorResponse](docs/UnifiedExtractorResponse.md)
 - [UniqueKeyConfig](docs/UniqueKeyConfig.md)
 - [UpdateNamespaceRequest](docs/UpdateNamespaceRequest.md)
 - [UpdateObjectRequest](docs/UpdateObjectRequest.md)
 - [UpdatePreferencesRequest](docs/UpdatePreferencesRequest.md)
 - [UpdatePublishedRetrieverRequest](docs/UpdatePublishedRetrieverRequest.md)
 - [UpdateReminderPreferencesRequest](docs/UpdateReminderPreferencesRequest.md)
 - [UpdateSecretRequest](docs/UpdateSecretRequest.md)
 - [UpdateSpendingCapsRequest](docs/UpdateSpendingCapsRequest.md)
 - [UploadListStats](docs/UploadListStats.md)
 - [UploadPerformanceMetric](docs/UploadPerformanceMetric.md)
 - [UploadPerformanceResponse](docs/UploadPerformanceResponse.md)
 - [UploadResponse](docs/UploadResponse.md)
 - [UsageBreakdownResponse](docs/UsageBreakdownResponse.md)
 - [UsageMetric](docs/UsageMetric.md)
 - [UsageStatistics](docs/UsageStatistics.md)
 - [UserCreateRequest](docs/UserCreateRequest.md)
 - [UserRole](docs/UserRole.md)
 - [UserStatus](docs/UserStatus.md)
 - [UserUpdateRequest](docs/UserUpdateRequest.md)
 - [UuidIndexParams](docs/UuidIndexParams.md)
 - [ValidateMigrationRequest](docs/ValidateMigrationRequest.md)
 - [ValidateMigrationResponse](docs/ValidateMigrationResponse.md)
 - [ValidateResult](docs/ValidateResult.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [ValidationResult](docs/ValidationResult.md)
 - [Value](docs/Value.md)
 - [VectorBasedConfigInput](docs/VectorBasedConfigInput.md)
 - [VectorBasedConfigOutput](docs/VectorBasedConfigOutput.md)
 - [VectorDataType](docs/VectorDataType.md)
 - [VectorIndex](docs/VectorIndex.md)
 - [VectorIndexDefinition](docs/VectorIndexDefinition.md)
 - [VectorPurpose](docs/VectorPurpose.md)
 - [VectorType](docs/VectorType.md)
 - [Vectors](docs/Vectors.md)
 - [VerifyPasswordRequest](docs/VerifyPasswordRequest.md)
 - [VerifyPasswordResponse](docs/VerifyPasswordResponse.md)
 - [WebScraperExtractorParams](docs/WebScraperExtractorParams.md)
 - [WebhookChannelInput](docs/WebhookChannelInput.md)
 - [WebhookChannelOutput](docs/WebhookChannelOutput.md)
 - [WebhookConfig](docs/WebhookConfig.md)
 - [WebhookEventType](docs/WebhookEventType.md)
 - [WebhookInput](docs/WebhookInput.md)
 - [WebhookOutput](docs/WebhookOutput.md)
 - [WeightLearningConfig](docs/WeightLearningConfig.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author

info@mixpeek.com


